// **********************************************************************************************************************************************
// Pepper card types recognition                                          treibauf AG, Switzerland, 01.06.2012 // updated with Pepper 11.1.1.5754
// **********************************************************************************************************************************************
// http://en.wikipedia.org/wiki/List_of_Bank_Identification_Numbers#List_of_bank_identification_numbers
// 
// This file enables Pepper to recognise the processed card types.
// In order for Pepper to use this file, it has to be placed in the working directory of Pepper, and must be named 'cardtypes.pep'.
// Its content is loaded into Pepper only once. If changes are made in this file, Pepper should be restarted to make the changes effective.
//
// Comment lines (starting with "//") and empty lines (CR+LF) will not be interpreted.
//
// Each line represents a card type recognition entry. It consists of terminal type, input, output and cardname.
// The format for each entry is: 'terminaltype.[input]=output{,cardname};'
// Pepper internally converts everything to lower-case and thus is not case sensitive.
// All leading and trailing spaces of an entry are stripped off.
// Prefixes can be used as input. A prefix input has the following syntax: '+preYES,-preNO,...'.
// A prefix 'preYES' is searched, and it matches only if there are no 'preNO' that matches too.
// Example: The key is '6.[+591,-59184,-59185]=302;' ==> '59186324324' will match, whereas '59184324234' won't match.
// The order you enter the prefix keys is relevant; the first match will be applied.
// Multiple card type recognition entries with the same result could be combined; again the first match will be applied.
//
// Each terminal type has a specific card recognition, based on different keys.
// For this reason, the comments concerning the method for the card recognition must be strictly observed.
//
// Values for terminal types:
//   0 (CH VEZ ASCOM),
//   1 (CH VEZ SIX CARD SOLUTIONS),
//   2 (CH VEZ EPSYS),
//   3 (CH VEZ CASH),
//   4 (CH VEZ CCREDIT),
//   5 (AT FIRST DATA),
//   6 (SI BANKART),
//   7 (CH SIX CARD SOLUTIONS MPD),
//   8 (DE ZVT GENERIC),
//   9 (DE INGENICO U16),
//  10 (DE HYPERCOM ARTEMA),
//  11 (CH ACCARDA VIRTUAL CLIENT),
//  12 (BE ATOS WORLDLINE),
//  13 (SIMPATICO EFT-SIMULATOR),
//  14 (CH VEZ PAYSYS),
//  15 (CH ADUNO OPTIMUM),
//  16 (US VERIFONE PCCHARGE),
//  17 (CH VEZ+ SIX CARD SOLUTIONS),
//  18 (DE HYPERCOM/THALES EFT Library),
//  19 (SI SIX CARD SOLUTIONS MPD),
//  20 (CH INGENICO),
//  21 (AT/LU SIX CARD SOLUTIONS MPD),
//  22 (SI CCV ZVT),
//  23 (CZ INGENICO CZESKA SPORITELNA),
//  24 (FR INGENICO CONCERT),
//  25 (DE INGENICO U32),
//  26 (CH ADUNO VERDI),
//  27 (CH ADUNO BLADE)
//  28 (NL XENTA VIC),
//  29 (AT CARD COMPLETE SMART),
//  30 (DE ELPAY),
//  31 (IT INGENICO),
//  32 (ES INGENICO),
//  33 (PL FIRST DATA / POLCARD),
//  34 (AT PAYLIFE),
//  35 (CH CCV JERONIMO CCVJIL.DLL),
//  36 (FR/ES/UK INGENICO C3 / AXIS),
//  37 (CH INNOCARD ARTEMA),
//  38 (CH INNOCARD OPTIMUM),
//  39 (DE PAYSYS),
//  40 (SK SLOVENSKA SPORITELNA),
//  41 (CH MFGROUP PAYMENT SERVER GATEWAY),
//  42 (DE/AT/LU EASYCASH PREPAYPLUS),
//  43 (DE/AT/CH CARDS & SYSTEMS IBRO30),
//  44 (CH INNOCARD, ICP BIA),
//  45 (RESERVED FOR FUTURE USE),
//  46 (SE/DK/NO/FI/BALTIC STATES/PL BAXI),
//  47 (RESERVED FOR FUTURE USE),
//  48 (RESERVED FOR FUTURE USE),
//  49 (US VERIFONE PCCHARGE THIN CLIENT),
//
// Values for output, representing the card type that will be assigned:
// -------------------------------------Card not recognized-------------------------------------
// 0 = UNKNOWN
// -------------------------------------International cards-------------------------------------
// 1 = MAESTRO
// 2 = MASTERCARD
// 3 = JCB
// 4 = DINERS
// 5 = VISA
// 6 = AMEX
// 7 = JAPAN AIRLINES
// 8 = EAPS (Euro Alliance of Payment Schemes)
// 9 = GIROCARD
// 10= VISA ELECTRON
// 11= V PAY
// 12= CUP (China Union Pay)
// -------------------------------------Swiss cards-------------------------------------
// 100 = MAESTRO-CH
// 101 = M-CARD
// 102 = POSTCARD
// 103 = BERN CARD
// 104 = ZUERI-CARD
// 105 = BASLER-CARD
// 106 = CASH
// 107 = PHARMACARD (former COVERCARD)
// 108 = MOEVENPICK
// 109 = ACCESSARENA
// 110 = SHOPPINGBONUS
// 111 = MYONE
// 112 = ORANGE
// 113 = SUNRISE
// 114 = SWISSCOM
// 115 = ACCARDA
// 116 = COOP SUPERCARD PLUS MASTERCARD
// 117 = POWERCARD
// 118 = WIR
// 119 = IKEA-CARD
// 120 = REKA
// 121 = STAEDTECARD
// 122 = JGIFT (JELMOLI)
// 123 = ADUNO KUNDENKARTE
// 124 = SWISS BONUS CARD
// 125 = ABO CARD (Aduno)
// 126 = MEDIAMARKT CARD
// 127 = YALLO
// 128 = COOP MOBILE
// 129 = PHONECARD
// 130 = ORANGECLICK.CH
// 131 = M-BUDGET MOBILE
// 132 = M-BUDGET
// 133 = GIFTCARD (SIX)
// 134 = COOP SUPERCARD PLUS VISA
// 135 = LOKALKARTE (READ OVER USB-PORT)
// 136 = SWISSCADEAU
// 137 = JELMOLI PAYCARD
// 138 = BARRACUDA TEMPCARD
// 139 = CONFORAMA CARD
// 140 = BONGENIE/GRIEDER CARD
// 141 = GIFT CARD BILLAG
// 142 = ADUNO TEST
// 143 = POSTFINANCE MOBILE COUPONING
// 144 = POSTFINANCE MOBILE PAYMENT
// 145 = KUNDENKARTE OFAC
// 146 = REINVEST SELECT COMPANY CARD
// 147 = KUNDENKARTE PKZ
// 148 = JUBIN CARD
// 149 = INNOCARD KUNDENKARTE
// 150 = ABO CARD
// 151 = SWISS HAPPY CARD
// 152 = SWISS CADEAU
// 153 = DATA STANDARDS
// 154 = SWISSBONUS+
// 155 = SWISS BONUS CARD
// 156 = GE MONEY BANK
// 157 = BARRACUDA TEMPCARD
// 158 = MERGER CARD
// 159 = MERGER CARD 2
// 160 = BONCARD POINTS (CUSTOMER LOYALTY SYSTEM)
// 161 = BONCARD PAY (BONCARD VOUCHER)
// 162 = FNAC-KARTE
// 163 = COMMIT CARD COMPANY CARD
// 164 = KUNDENKARTE LOEB
// 165 = EXLIBRIS GESCHENKKARTE
//-------------------------------------Austrian cards-------------------------------------
// 200 = QUICK
// 201 = MAESTRO_AT
// 203 = IKEA FAMILY PAYCARD
// 204 = FLOTTENKARTE (TYP 4)
// 217 = AUSTRIA CARD
// 218 = OEBB VORTEILSKARTE
// 219 = SHOPIN-KARTE
// 220 = TLAPA-KARTE
//-------------------------------------Slovenian cards-------------------------------------
// 300 = ACTIVA NAVADNA
// 301 = BA DEBIT CARD
// 302 = KARANTA
//-------------------------------------German cards-------------------------------------
// 401 = MAESTRO_DE
// 402 = GELDKARTE
// 403 = IKEA FAMILY PLUS
// 405 = GOBANANAS
// 409 = GIROCARD DEUTSCHE LASTSCHRIFT
// 410 = MAESTRO ELV
// 411 = MAESTRO OLV
// 412 = EC-CASH	
// 414 = ANNICARD
// 420 = HORNBACH PROFI
// 421 = HORNBACH WELT
// 422 = HORNBACH GUTSCHEINKARTE
// 431 = PREMIERE FLEX
// 438 = BREUNINGER
// 440 = INTERCARD GUTSCHEINKARTE
// 441 = T-D1 XTRA
// 442 = COMFORT CARD
// 452 = PAYSAFECARD
// 479 = VODAFONE CALLYA
// 480 = E-PLUS FREE&EASY
// 481 = O2 LOOP	
// 482 = TEST PINPRINTING
// 483 = GESCHENKGUTSCHEIN
// 484 = SCHLECKER PREPAID
// 485 = VITALSANA
// 486 = SCHLECKER SMOBIL
// 487 = SCHLECKER ZUSATZPRODUKTE
// 488 = FONIC
// 489 = BILDMOBIL
// 490 = BLAU.DE
// 491 = CONGSTAR
// 492 = LEBARA MOBILE
// 493 = SIMYO
// 494 = LYCAMOBILE
// 495 = GT MOBILE
// 496 = AVS GUTSCHEINKARTE
//-------------------------------------Belgian cards-----------------------------------
// 500 = BANCONTACT/MISTER CASH
// 501 = PROTON
// 502 = AURORA
// 503 = KADOZ
//-------------------------------------US cards----------------------------------------
// 600 = DISCOVER
// 601 = CARTE BLANCHE
//-------------------------------------Dutch cards-------------------------------------
// 700 = BANCONTACT/MISTER CASH
// 701 = GIRO
// 702 = EPWS
// 704 = CMFC
// 705 = PRLI
// 706 = BASIC CARD
// 707 = SCHOENENBON
// 708 = FASHION CARD
// 709 = CCV CARD
// 710 = YOURGIFT H&G
// 711 = YOURGIFT G&M
// 712 = YOURGIFT M&M
// 713 = YOURGIFT B&H
// 714 = YOURGIFT H&T
// 715 = YOURGIFT F&F
// 716 = YOURGIFT W&D
// 717 = YOURGIFT G&C
//-------------------------------------Italian cards----------------------------------
// 801 = PAGOBANCOMAT
// 802 = KEY CLIENT
// 803 = CARTASI
// 804 = AGOS
// 805 = FINDOMESTIC
//-------------------------------------French cards-----------------------------------
// 900 = CARTE BLEUE (DOMESTIC VISA)
// 901 = ACCORD
// 902 = ALPHYRA (Payzone)
// 903 = CAFETERIA CASINO
// 904 = AUCHAN TELECOM
// 905 = PNF CREDIT MUTUEL
// 906 = EMPLOYE ED
// 907 = EVEREST
// 908 = COFINOGA
// 909 = CHEQUE
// 910 = CALEDINIENNE DE SERVICE BANCAIRE
// 911 = AURORE
// 912 = DATAVANTAGE (GIFTCARD) 
// 913 = EDEL, LECLERC
// 914 = ELF (Total, Parking)
// 915 = PLURIEL - FRANFINANCE
// 916 = FNAC
// 917 = FINAREF
// 918 = GAV (Gestion de Avoirs) 
// 919 = GLF (Galerie Lafayette) 
// 920 = MGL (Magellan)
// 921 = MULTISSIME
// 922 = OPTALION (crdit Lyonnais)
// 923 = PASS
// 924 = PGS (Pegasus)
// 925 = PME (Mono - Porte Monnaie Electronique)
// 926 = PROMOSTIM (Record Card)
// 927 = PROSODIE
// 928 = SOFINCO
// 929 = SODELEM (carte ptrole)
// 930 = SMILES
// 931 = CETELEM
// 932 = MODEUS
// 933 = CARTE PINAULT PRINTEMPS REDOUTE
//-------------------------------------Luxembourgian cards----------------------------------
// 1000 = BANCOMAT LUXEMBOURG
// 1001 = AURORA LUXEMBOURG
// 1002 = HORNBACH PROFICARD LUXEMBOURG
//-------------------------------------Scandinavian cards-----------------------------------
// 1100 = DANKORT
// 1101 = VISA DANMARK
// 1102 = MASTERCARD DK
// 1103 = MAESTRO DK
// 1104 = DINERS DK
// 1105 = AMEX DK
// 1106 = PBS KJEDEKORT / GAVEKORT
// 1107 = PBS CENTERKORT
// 1108 = FORBRUGSFORENINGEN
// 1109 = IKANO FINANS
// 1110 = SPAREXPRESS
//------------------------------------- Values for cardname -------------------------------------
// A card name can be set to overwrite missing or an existing, but wrong, card label. 
// This value is optional, and disregarded, if not set.
//-----------------------------------------------------------------------------------------------
//
// **********************************************************************************************************************************************
// Terminal type 0 (CH ASCOM):  /Extension for PaySys
// The card recognition is based on the ISSUER NUMBER
// **********************************************************************************************************************************************
// remove comments from lines starting by a 0 if ASCOM Terminal or ASCOM EFT simulator is used
//
// MAESTRO ----------------------------
//0.[9]=1;
//0.[09]=1;
// MASTERCARD -------------------------
//0.[4]=2;
//0.[04]=2;
// DINERS -----------------------------
//0.[6]=4;
//0.[06]=4;
// VISA -------------------------------
//0.[7]=5;
//0.[07]=5;
// AMEX -------------------------------
//0.[5]=6;
//0.[05]=6;
// MAESTRO CH -------------------------
//0.[2]=100;
//0.[02]=100;
// M-CARD -----------------------------
//0.[1]=101;
//0.[01]=101;
// POSTCARD ---------------------------
//0.[3]=102;
//0.[03]=102;
// BERN CARD --------------------------
//0.[89]=103;
// ZUERI CARD -------------------------
//0.[90]=104;
//
//if PaysSys is used in Ascom Modus
//
// MAESTRO ----------------------------
0.[7]=1;
0.[07]=1;
// MASTERCARD -------------------------
0.[2]=2;
0.[02]=2;
// JCB --------------------------------
0.[6]=3;
0.[06]=3;
// DINERS -----------------------------
0.[43]=4;
// VISA -------------------------------
0.[5]=5;
0.[05]=5;
// AMEX -------------------------------
0.[40]=6;
// MAESTRO CH -------------------------
0.[1]=100;
0.[01]=100;
// M-CARD -----------------------------
0.[22]=101;
// POSTCARD ---------------------------
0.[21]=102;
// STAEDTE CARD -----------------------
0.[41]=103;
0.[42]=103;
0.[45]=103;
// CASH -------------------------------
0.[8]=106;
0.[08]=106;
// PHARMACARD --------------------------
0.[55]=107;
// MOEVENPICK -------------------------
0.[46]=108;
// MOEVENPICK -------------------------
0.[81]=110;
// MYONE ------------------------------
0.[84]=111;
//COOP SUPERCARD PLUS MASTERCARD-------
0.[24]=116;
//COOP SUPERCARD PLUS VISA-------------
0.[26]=134;
//BONCARD
0.[66]=160,BONARD POINTS;
0.[67]=161,BONCARD PAY;
// **********************************************************************************************************************************************
// Terminal type 1 (CH SIX CARD SOLUTIONS  / AID Brandtabelle 03.08.2010):
// The card recognition is based on the ISSUER NUMBER
// **********************************************************************************************************************************************
// MAESTRO ----------------------------
1.[7]=1;
1.[07]=1;
// MASTERCARD -------------------------
1.[2]=2;
1.[02]=2;
// M-Budget MasterCard
1.[25]=2;
// JCB --------------------------------
1.[6]=3;
1.[06]=3;
// DINERS -----------------------------
1.[43]=4;
// VISA / VISA ELECTRON ---------------
1.[5]=5;
1.[05]=5;
// V PAY ------------------------------
1.[96]=11,V PAY;
// AMEX -------------------------------
1.[40]=6;
//BANCOMAT CETREL LUXEMBOURG ----------
1.[30]=1000,BANCOMAT LUXEMOURG;
//AURORA LUXEMBOURG -------------------
1.[31]=1001,AURORA LUXEMBOURG;
// PHARMACARD -------------------------
1.[55]=107,PHARMACARD;
// MAESTRO CH -------------------------
1.[1]=100;
1.[01]=100;
//CUP ---------------------------------
1.[9]=12,CHINA UNION PAY;
1.[09]=12,CHINA UNION PAY;
// M-CARD -----------------------------
1.[22]=101;
// POSTCARD ---------------------------
1.[21]=102;
// BERN CARD --------------------------
1.[42]=103;
// ZUERI CARD, IKEA-CARD OR STAEDTECARD-
//1.[41]=104,ZUERI CARD;
1.[41]=119,IKEA-CARD   ; 
1.[+6004520306]=119,IKEA-CARD   ;
1.[91]=119,IKEA-CARD   ;
//1.[41]=121,STAEDTECARD;
1.[+60045203]=121,STAEDTECARD;
// BASLER CARD ------------------------
1.[45]=105;
// CASH -------------------------------
1.[8]=106;
1.[08]=106;
// JELMOLI BONUS SHOPPING CARD --------
1.[81]=110;
// JELMOLI PAYCARD --------------------
1.[a0000001574462]=137;
// MOEVENPICK -------------------------
1.[46]=108;
// MANOR CARD myONE -------------------
1.[84]=111;
// ORANGE -----------------------------
1.[75]=112;
// SUNRISE ----------------------------
1.[76]=113;
// SWISSCOM ---------------------------
1.[77]=114;
//COOP SUPERCARD PLUS MASTERCARD-------
1.[24]=116;
//COOP SUPERCARD PLUS VISA-------------
1.[26]=134;
// POWERCARD --------------------------
1.[87]=117;
//GIFT CARD ACCARDA -------------------
1.[88]=115;
// WIR --------------------------------
1.[50]=118; 
//REKA  -------------------------------
1.[90]=120;
// JGIFT (JELMOLI)---------------------
1.[72]=122,J-Geschenkkarte;
// COMMTRAIN/ADUNO CARDS --------------
// MEDIAMARKT -------------------------
1.[89]=126,Mediamarkt Card;
// YALLO ------------------------------
1.[73]=127,Yallo;
// COOP MOBILE ------------------------
1.[78]=128,Coop Mobile;
// PHONECARD ---------------------------
1.[79]=129,phoneCard;
// ORANGECLICK.CH ----------------------
1.[80]=130,orangeclick.ch;
// M-BUDGET MOBILE ---------------------
1.[82]=131,M-Budget Mobile;
// GIFTCARD (SIX)-----------------------
1.[97]=133,GiftCard;
//BONCARD
1.[66]=160,BONARD POINTS;
1.[67]=161,BONCARD PAY;
//
// **********************************************************************************************************************************************
// Terminal type 2 (CH EPSYS):
// The card recognition is based on the ISSUER NUMBER
// **********************************************************************************************************************************************
// MAESTRO ----------------------------
2.[7]=1;
2.[07]=1;
// MASTERCARD -------------------------
2.[2]=2;
2.[02]=2;
// M-Budget MasterCard
2.[25]=2;
// JCB --------------------------------
2.[6]=3;
2.[06]=3;
// DINERS -----------------------------
2.[43]=4;
// VISA / VISA ELECTRON ---------------
2.[5]=5;
2.[05]=5;
// V PAY ------------------------------
2.[96]=11,V PAY;
// AMEX -------------------------------
2.[40]=6;
//BANCOMAT LUXEMBOURG -----------------
2.[30]=1000,BANCOMAT LUXEMBOURG;
//AURORA LUXEMBOURG -------------------
2.[31]=1001,AURORA LUXEMBOURG;
// PHARMACARD -------------------------
2.[55]=107,PHARMACARD;
// MAESTRO CH -------------------------
2.[1]=100;
2.[01]=100;
//CUP ---------------------------------
2.[9]=12,CHINA UNION PAY;
2.[09]=12,CHINA UNION PAY;
// M-CARD -----------------------------
2.[22]=101;
// POSTCARD ---------------------------
2.[21]=102;
// BERN CARD --------------------------
2.[42]=103;
// ZUERI CARD, IKEA-CARD OR STAEDTECARD-
//2.[41]=104,ZUERI CARD;
2.[41]=119,IKEA-CARD   ; 
2.[+6004520306]=119,IKEA-CARD   ;
2.[91]=119,IKEA-CARD   ;
//2.[41]=121,STAEDTECARD;
2.[+60045203]=121,STAEDTECARD;
// BASLER CARD ------------------------
2.[45]=105;
// CASH -------------------------------
2.[8]=106;
2.[08]=106;
// JELMOLI BONUS SHOPPING CARD --------
2.[81]=110;
// JELMOLI PAYCARD --------------------
2.[a0000001574462]=137;
// MOEVENPICK -------------------------
2.[46]=108;
// MANOR CARD myONE -------------------
2.[84]=111;
// ORANGE -----------------------------
2.[75]=112;
// SUNRISE ----------------------------
2.[76]=113;
// SWISSCOM ---------------------------
2.[77]=114;
//COOP SUPERCARD PLUS MASTERCARD-------
2.[24]=116;
//COOP SUPERCARD PLUS VISA-------------
2.[26]=134;
// POWERCARD --------------------------
2.[87]=117;
//GIFT CARD ACCARDA -------------------
2.[88]=115;
// WIR --------------------------------
2.[50]=118; 
//REKA  -------------------------------
2.[90]=120;
// JGIFT (JELMOLI)---------------------
2.[72]=122,J-Geschenkkarte;
// COMMTRAIN/ADUNO CARDS --------------
// MEDIAMARKT -------------------------
2.[89]=126,Mediamarkt Card;
// YALLO ------------------------------
2.[73]=127,Yallo;
// COOP MOBILE ------------------------
2.[78]=128,Coop Mobile;
// PHONECARD ---------------------------
2.[79]=129,phoneCard;
// ORANGECLICK.CH ----------------------
2.[80]=130,orangeclick.ch;
// M-BUDGET MOBILE ---------------------
2.[82]=131,M-Budget Mobile;
// GIFTCARD (SIX)-----------------------
2.[97]=133,GiftCard;
//BONCARD
2.[66]=160,BONARD POINTS;
2.[67]=161,BONCARD PAY;
//
// **********************************************************************************************************************************************
// Terminal type 3 (CH CASH):
// The card recognition is based on the ISSUER NUMBER
// (The only possible card that can be used, is the CASH Card)
// **********************************************************************************************************************************************
// CASH -------------------------------
3.[1]=106;
3.[01]=106;
//
// **********************************************************************************************************************************************
// Terminal type 4 (CH CCREDIT):
// The card recognition is based on the ISSUER NUMBER and Application-ID
// **********************************************************************************************************************************************
// MAESTRO ----------------------------
4.[7]=1;
4.[07]=1;
// MASTERCARD -------------------------
4.[2]=2;
4.[02]=2;
//M-Budget MasterCard
4.[25]=2;
// JCB --------------------------------
4.[6]=3;
4.[06]=3;
// DINERS -----------------------------
4.[43]=4;
// VISA / VISA ELECTRON ---------------
4.[5]=5;
4.[05]=5;
//V PAY -------------------------------
4.[96]=11,V PAY;
4.[+A0000000032020]=11,V PAY;
4.[A0000001574452]=11,V PAY;
// CUP (China UnionPay)----------------
4.[9]=12,CUP;
4.[09]=12,CUP;
// AMEX -------------------------------
4.[40]=6;
4.[a000000025010402]=6;
// MAESTRO CH -------------------------
4.[1]=100;
4.[01]=100;
// M-CARD -----------------------------
4.[22]=101;
// POSTCARD ---------------------------
4.[21]=102;
// STAEDTECARD -(choose your card here)-
//4.[41]=103,BERN CARD;
4.[41]=104,ZUERI-CARD;
//4.[41]=105,BASLER-CARD;
// JELMOLI SHOPPING BONUS CARD --------
4.[81]=110;
// JELMOLI PAYCARD --------------------
4.[a0000001574462]=137;
// MANOR CARD myONE -------------------
4.[84]=111;
// ORANGE -----------------------------
4.[75]=112;
// Sunrise ----------------------------
4.[76]=113;
// SWISSCOM ---------------------------
4.[77]=114;
//COOP SUPERCARD PLUS MASTERCARD-------
4.[24]=116;
//COOP SUPERCARD PLUS VISA-------------
4.[26]=134;
// WIR --------------------------------
4.[50]=118;
// PHARMACARD -------------------------
4.[55]=107,PHARMACARD;
// SWISS BONUS CARD -------------------
4.[56]=124,SWISS BONUS CARD;
// REKA -------------------------------
4.[90]=120;
// ABO CARD ---------------------------
4.[95]=125,ABO Card;
// YALLO ------------------------------
4.[73]=127,Yallo;
// COOP MOBILE ------------------------
4.[78]=128,Coop Mobile;
// PHONECARD ---------------------------
4.[79]=129,phoneCard;
// ORANGECLICK.CH ----------------------
4.[80]=130,orangeclick.ch;
// M-BUDGET MOBILE ---------------------
4.[82]=131,M-Budget Mobile;
//POWERCARD (MF Group) -----------------
4.[87]=117;
4.[a00000015701]=117;
//SWISSCADEAU --------------------------
4.[A000000157445A]=136,SWISSCADEAU;
//KUNDENKARTE BONGENIE/GRIEDER ---------
4.[A000000157445E]=140,BonGenie/Grieder Card; 
//BONCARD ------------------------------
4.[A0000001574455]=160,BONARD POINTS;
4.[A000000157445B]=161,BONCARD PAY;
4.[66]=160,BONARD POINTS;
4.[67]=161,BONCARD PAY;
//
// **********************************************************************************************************************************************
// Terminal type 5 (AT APSS):
// The card recognition is based on the CARD NAME, given by the interface.
// (As default field m_name or, in the case of debit cards, the 3 first characters of p_text)
// **********************************************************************************************************************************************
// MAESTRO PIN based-------------------
5.[edc]=1;
// MASTERCARD PIN based----------------
5.[KMC]=2;
// MASTERCARD signature based----------
5.[+mastercard]=2;
5.[+mc ]=2;
// JCB PIN based-----------------------
5.[KJB]=3;
// JCB signature based-----------------
5.[+jcb]=3;
// DINERS PIN based--------------------
5.[KDI]=4;
// DINERS signature based--------------
5.[+diners]=4;
// VISA ELECTRON-----------------------
5.[+visa elec]=10;
// V PAY-------------------------------
5.[+v pay]=11;
5.[KVP]=11;
// VISA PIN based----------------------
5.[KVI]=5;
// VISA signature based----------------
5.[+visa]=5;
5.[citibank visa]=5;
5.[hanseatic bank]=5;
5.[anzsmartpay]=5;
5.[ykb worldcard]=5;
// AMEX PIN based----------------------
5.[KAM]=6;
// AMEX signature based----------------
5.[+american]=6;
5.[+amex]=6;
// QUICK PIN based---------------------
5.[QCK]=200;
// BANKOMAT (MAESTRO AT) PIN based-----
5.[B-K]=201;
// BANKOMAT PIN based (not guaranteed)-
5.[BKN]=201;
5.[bkn]=201;
// JAPAN AIRLINES ---------------------
5.[+japan]=7;
// Euro Alliance of Payment Schemes----
5.[+eaps]=8;
// GIROCARD----------------------------
5.[+giro]=9;
// CUP (China UnionPay)----------------
5.[+cup]=12;
5.[+KCU]=12;
5.[+china]=12;
// FLOTTENKARTE (TYP 4)
5.[TYP4]=204,Flottenkarte;
// LOKALE KARTE (TYP3)
5.[TYP3]=205;
//
// **********************************************************************************************************************************************
// Terminal type 6 (SI BANKART):
// The card recognition is primarily based on the CARD NAME and secondly on the CARD NUMBER PREFIX.
// **********************************************************************************************************************************************
// ACTIVA NAVADNA ---------------------
6.[+activa]=300;
6.[+0059]=300;
// BA DEBIT CARD ----------------------
6.[ba kartica]=301;
6.[ba/maestro]=301;
6.[nlb ba]=301;
6.[+676226]=301;
6.[+676268]=301;
6.[+676270]=301;
6.[+676324]=301;
6.[+676325]=301;
6.[+676326]=301;
6.[+676327]=301;
6.[+676385]=301;
6.[+676412]=301;
6.[+677137]=301;
6.[+677141]=301;
6.[+677143]=301;
6.[+677152]=301;
6.[+677181]=301;
6.[+677173]=301;
6.[+677192]=301;
6.[+677195]=301;
// KARANTA ----------------------------
6.[karanta]=302;
6.[nlb karanta]=302;
6.[+591,-59184,-59185]=302;
// MAESTRO ----------------------------
6.[+maestro]=1;
6.[nlb maestro]=1;
6.[+56]=1;
6.[+57]=1;
6.[+58]=1;
6.[+59]=1;
6.[+6]=1;
// MASTERCARD -------------------------
6.[+eurocard]=2;
6.[+master]=2;
6.[+50]=2;
6.[+51]=2;
6.[+52]=2;
6.[+53]=2;
6.[+54]=2;
6.[+55]=2;
// DINERS -----------------------------
6.[diners]=4;
6.[+36]=4;
6.[+38]=4;
6.[+39]=4;
// VISA -------------------------------
6.[+visa]=5;
6.[+4]=5;
// AMEX -------------------------------
6.[+centurion]=6;
6.[+amex]=6;
6.[+34]=6;
6.[+37]=6;
//
// **********************************************************************************************************************************************
// Terminal type 7 (CH SIX CARD SOLUTIONS MPD / AID Brandtabelle 03.08.2010): 
// The card recognition is based on AID, ISSUER NUMBER, Card Number and Card Name
// **********************************************************************************************************************************************
// where Issuer-Nbr exist do not use AID, rely on Issuer-Nbr from terminal
// MAESTRO ----------------------------
7.[7]=1;
7.[07]=1;
// MASTERCARD -------------------------
7.[2]=2;
7.[02]=2;
// M-Budget MasterCard
7.[25]=2;
// JCB --------------------------------
7.[06]=3;
7.[6]=3;
// DINERS -----------------------------
7.[43]=4;
// VISA / VISA ELECTRON ---------------
7.[5]=5;
7.[05]=5;
// V PAY ------------------------------
7.[96]=11,V PAY;
7.[A0000000032020]=11,V PAY; 
7.[V PAY]=11,V PAY;
// AMEX -------------------------------
7.[40]=6;
// BANCOMAT LUXEMBOURG ----------------
7.[30]=1000,BANCOMAT LUXEMBOURG;
// AURORA LUXEMBOURG ------------------
7.[31]=1001,AURORA LUXEMBOURG;
// PHARMACARD -------------------------
7.[55]=107,PHARMACARD;
// MAESTRO CH -------------------------
7.[1]=100;
7.[01]=100;
// CUP --------------------------------
7.[9]=12,CHINA UNION PAY;
7.[09]=12,CHINA UNION PAY;
// M-CARD -----------------------------
7.[22]=101;
// POSTCARD ---------------------------
7.[21]=102;
// BERN CARD --------------------------
7.[42]=103;
// ZUERI CARD, IKEA-CARD OR STAEDTECARD-
//7.[41]=104,ZUERI CARD;
7.[41]=119,IKEA-CARD   ; 
7.[+6004520306]=119,IKEA-CARD   ;
7.[91]=119,IKEA-CARD   ;
//7.[41]=121,STAEDTECARD;
7.[+60045203]=121,STAEDTECARD; 
// BASLER CARD ------------------------
7.[45]=105;
// CASH -------------------------------
7.[8]=106;
7.[08]=106;
// JELMOLI BONUS SHOPPING CARD --------
7.[81]=110;
// JELMOLI PAYCARD --------------------
7.[a0000001574462]=137;
// MOEVENPICK -------------------------
7.[46]=108;
// MANOR CARD myONE -------------------
7.[84]=111; 
// ORANGE -----------------------------
7.[75]=112;
// SUNRISE ----------------------------
7.[76]=113;
// SWISSCOM ---------------------------
7.[77]=114;
//COOP SUPERCARD PLUS MASTERCARD-------
7.[24]=116;
//COOP SUPERCARD PLUS VISA-------------
7.[26]=134;
// POWERCARD --------------------------
7.[87]=117;
//GIFT CARD ACCARDA -------------------
7.[88]=115;
// WIR --------------------------------
7.[50]=118; 
//REKA  -------------------------------
7.[90]=120;
// JGIFT (JELMOLI)---------------------
7.[72]=122,J-Geschenkkarte;
// COMMTRAIN/ADUNO CARDS --------------
// MEDIAMARKT -------------------------
7.[89]=126,Mediamarkt Card;
// YALLO ------------------------------
7.[73]=127,Yallo;
// COOP MOBILE ------------------------
7.[78]=128,Coop Mobile;
// PHONECARD ---------------------------
7.[79]=129,phoneCard;
// ORANGECLICK.CH ----------------------
7.[80]=130,orangeclick.ch;
// M-BUDGET MOBILE ---------------------
7.[82]=131,M-Budget Mobile;
// GIFTCARD (SIX)-----------------------
7.[97]=133,GiftCard;
//SWISSCADEAU---------------------------
7.[A000000157445A]=136,SWISSCADEAU;
//KUNDENKARTE BONGENIE/GRIEDER ---------
7.[A000000157445E]=140,BonGenie/Grieder Card; 
7.[+636265]=140,BonGenie/Grieder Card;
//BONCARD
7.[66]=160,BONARD POINTS;
7.[67]=161,BONCARD PAY;
//
// **********************************************************************************************************************************************
// Terminal type 8 (DE ZVT-700-KMS):
// The card recognition is based on CARD TYPE (Kartenart BMP 8A) and PAYMENT TYPE (Zahlart BMP 19).
// **********************************************************************************************************************************************
// CHINA UNION PAY ---------------------
8.[198]=12,CHINA UNION PAY;
// girocard ---------------------------
8.[5]=9,GIROCARD;
// EAPS -------------------------------
8.[7]=8,EAPS;
// girocard deutsche Lastschrift ------
8.[9]=409,GIROCARD DE LASTSCHRIFT;
// VISA electron ----------------------
8.[11]=10,VISA ELECTRON;
// V PAY ------------------------------
8.[13]=11,V PAY;
//-------------- end new card types TA 7.0 -------------
// MAESTRO ----------------------------
8.[46]=1;
// MASTERCARD -------------------------
8.[6]=2;
// DINERS -----------------------------
8.[12]=4;
// VISA -------------------------------
8.[10]=5;
// AMEX -------------------------------
8.[8]=6;
// JCB --------------------------------
8.[14]=3;
// MAESTRO DE / ELV -------------------
8.[2ELV]=410;
// MAESTRO DE / OLV -------------------
8.[2OLV]=411;
// MAESTRO DE / ec-CASH ---------------
8.[2CASH]=412;
// MAESTRO DE / default ---------------
8.[2]=401;
// GELDKARTE --------------------------
8.[30]=402;
// IKEA FAMILY PLUS -------------------
8.[76]=403;
// HORNBACH Profi ---------------------
8.[137]=420,HORNBACH Profi;
// HORNBACH Welt ----------------------
8.[138]=421,HORNBACH Welt;
// HORNBACH Welt ----------------------
8.[157]=422,HORNBACH Gutscheinkarte; 
// INTERCARD GUTSCHEINKARTE------------
8.[240]=440,IC-Gutscheinkarte;
//-------------------------------------
// Comfort Card -----------------------
8.[42]=442,Comfort Card;
// Breuninger-- -----------------------
8.[38]=438,Breuninger;
//
// Prepaid Phone Cards ----------------
8.[+414]=414,AnniCard;
8.[+AnniCard]=414,AnniCard;
//
8.[212]=441,T-D1 XTRA;
8.[+T-D1 XTRA]=441,T-D1 XTRA;
8.[+T-D1]=441,T-D1 XTRA;
8.[+XTRA]=441,T-D1 XTRA;
//
8.[191]=479,Vodafone CallYa;
8.[+Vodafone CallYa]=479,Vodafone CallYa;
8.[+Vodafone]=479,Vodafone CallYa;
8.[+CallYa]=479,Vodafone CallYa;
//
8.[190]=480,E-Plus Free&Easy;
8.[+E-Plus Free&Easy]=480,E-Plus Free&Easy;
8.[+E-Plus]=480,E-Plus Free&Easy;
8.[+Free&Easy]=480,E-Plus Free&Easy;
//
8.[188]=481,O2 LOOP;
8.[+O2 LOOP]=481,O2 LOOP;
8.[+O2]=481,O2 LOOP;
8.[+LOOP]=481,O2 LOOP;
//
8.[+431]=431,Premiere Flex;
8.[+Premiere Flex]=431,Premiere Flex;
8.[+Premiere]=431,Premiere Flex;
8.[+Flex]=431,Premiere Flex;
//
8.[189]=405,gobananas;
8.[+gobananas]=405,gobananas;
//
8.[+352]=452,Paysafecard;
8.[+Paysafecard]=452,Paysafecard;
//
// TEST PINPRINTING----------------
8.[349]=482,TEST PINPRINTING;
// GESCHENKGUTSCHEIN---------------
8.[806]=483,GESCHENKGUTSCHEIN;
//SCHLECKER CARDS------------------
8.[807]=484,SCHLECKER PREPAID;
8.[249]=486,smobil;
8.[250]=487,Schlecker Zusatz;
//VITALSANA-----------------------
8.[808]=485,VITALSANA;
//MOBILE CARDS--------------------
8.[246]=488,FONIC;
8.[206]=489,BILDmobil;
8.[205]=490,Blau.de;
8.[207]=491,Congstar;
8.[475]=492,Lebara Mobile;
8.[248]=493,Simyo;
8.[884]=494,Lycamobile;
8.[917]=495,GT mobile;
//AVS -----------------------------
8.[253]=496,AVS Gutscheinkarte;
//
// 220 TLAPA-KARTE---------------------
8.[231]=220,TLAPA-KARTE; 
//
//For the function READ CARD the recognition must be done by the card number
// MAESTRO ----------------------------
8.[+67]=1;
// COMFORT CARD -----------------------
8.[+564191]=442,Comfort Card;
// MASTERCARD -------------------------
8.[+5]=2;
// DINERS -----------------------------
8.[+36]=4;
// VISA -------------------------------
8.[+4]=5;
// AMEX -------------------------------
8.[+37]=6;
// JCB --------------------------------
8.[+35]=3;
//
// **********************************************************************************************************************************************
// Terminal type 9 (DE INGENICO 5300 ZVT):
// The card recognition is based on CARD TYPE (Kartenart BMP 8A) and PAYMENT TYPE (Zahlart BMP 19).
// **********************************************************************************************************************************************
// CHINA UNION PAY ---------------------
9.[198]=12,CHINA UNION PAY;
//-----------------  new card types TA 7.0 --------------
// girocard ---------------------------
9.[5]=9,GIROCARD;
// EAPS -------------------------------
9.[7]=8,EAPS;
// girocard deutsche Lastschrift ------
9.[9]=409,GIROCARD DE LASTSCHRIFT;
// VISA electron ----------------------
9.[11]=10,VISA ELECTRON;
// V PAY ------------------------------
9.[13]=11,V PAY;
//-------------- end new card types TA 7.0 -------------
// MAESTRO ----------------------------
9.[21]=1;
// MASTERCARD -------------------------
9.[1]=2;
// DINERS -----------------------------
9.[4]=4;
// VISA -------------------------------
9.[3]=5;
// AMEX -------------------------------
9.[2]=6;
// MAESTRO DE / ELV -------------------
9.[0ELV]=410;
// MAESTRO DE / OLV -------------------
9.[0OLV]=411;
// MAESTRO DE / ec-CASH ---------------
9.[0CASH]=412;
// MAESTRO DE / default ---------------
9.[0]=401;
// GELDKARTE --------------------------
9.[30]=402;
// Comfort Card -----------------------
9.[42]=442,Comfort Card;
// Breuninger-- -----------------------
9.[38]=438,Breuninger;
// INTERCARD GUTSCHEINKARTE------------
9.[240]=440,IC-Gutscheinkarte;
//
// TEST PINPRINTING----------------
9.[349]=482,TEST PINPRINTING;
// GESCHENKGUTSCHEIN---------------
9.[806]=483,GESCHENKGUTSCHEIN;
//SCHLECKER CARDS------------------
9.[807]=484,SCHLECKER PREPAID;
9.[249]=486,smobil;
9.[250]=487,Schlecker Zusatz;
//VITALSANA-----------------------
9.[808]=485,VITALSANA;
//MOBILE CARDS--------------------
9.[246]=488,FONIC;
9.[206]=489,BILDmobil;
9.[205]=490,Blau.de;
9.[207]=491,Congstar;
9.[475]=492,Lebara Mobile;
9.[248]=493,Simyo;
9.[884]=494,Lycamobile;
9.[917]=495,GT mobile;
//AVS -----------------------------
9.[253]=496,AVS Gutscheinkarte;
//
//For the function READ CARD the recognition must be done by the card number
// MAESTRO ----------------------------
9.[+67]=1;
// COMFORT CARD -----------------------
9.[+564191]=442,Comfort Card;
// MASTERCARD -------------------------
9.[+5]=2;
// DINERS -----------------------------
9.[+36]=4;
// VISA -------------------------------
9.[+4]=5;
// AMEX -------------------------------
9.[+37]=6;
// JCB --------------------------------
9.[+35]=3;
//
// **********************************************************************************************************************************************
// Terminal type 10 (DE HYPERCOM ARTEMA DESK / ARTEMA HYBRID ZVT):
// The card recognition is based on CARD TYPE (Kartenart BMP 8A) and PAYMENT TYPE (Zahlart BMP 19).
// *******************************************************************************************************************************************
//-----------------  new card types TA 7.0 --------------
// CHINA UNION PAY ---------------------
10.[198]=12,CHINA UNION PAY;
// girocard ---------------------------
10.[5]=9,GIROCARD;
// EAPS -------------------------------
10.[7]=8,EAPS;
// girocard deutsche Lastschrift ------
10.[9]=409,GIROCARD DE LASTSCHRIFT;
// VISA electron ----------------------
10.[11]=10,VISA ELECTRON;
// V PAY ------------------------------
10.[13]=11,V PAY;
//-------------- end new card types TA 7.0 -------------
// MAESTRO ----------------------------
10.[46]=1;
// MASTERCARD -------------------------
10.[6]=2;
// DINERS -----------------------------
10.[12]=4;
// VISA -------------------------------
10.[10]=5;
// AMEX -------------------------------
10.[8]=6;
// JCB --------------------------------
10.[14]=3;
// MAESTRO DE / ELV -------------------
10.[2ELV]=410;
// MAESTRO DE / OLV -------------------
10.[2OLV]=411;
// MAESTRO DE / ec-CASH ---------------
10.[2CASH]=412;
// MAESTRO DE / default ---------------
10.[2]=401;
// GELDKARTE --------------------------
10.[30]=402;
// HORNBACH Profi ---------------------
10.[137]=420,HORNBACH Profi;
// HORNBACH Welt ----------------------
10.[138]=421,HORNBACH Welt;
// HORNBACH Welt ----------------------
10.[157]=422,HORNBACH Gutscheinkarte;
// INTERCARD GUTSCHEINKARTE------------
10.[240]=440,IC-Gutscheinkarte;
//-------------------------------------
// Comfort Card -----------------------
10.[42]=442,Comfort Card;
// Breuninger -------------------------
10.[38]=438,Breuninger;
//
// Prepaid Phone Cards ----------------
10.[+414]=414,AnniCard;
10.[+AnniCard]=414,AnniCard;
//
10.[212]=441,T-D1 XTRA;
10.[80]=441,T-D1 XTRA;
10.[+T-D1 XTRA]=441,T-D1 XTRA;
10.[+T-D1]=441,T-D1 XTRA;
10.[+XTRA]=441,T-D1 XTRA;
//
10.[191]=479,Vodafone CallYa;
10.[+Vodafone CallYa]=479,Vodafone CallYa;
10.[+Vodafone]=479,Vodafone CallYa;
10.[+CallYa]=479,Vodafone CallYa;
//
10.[190]=480,E-Plus Free&Easy;
10.[+E-Plus Free&Easy]=480,E-Plus Free&Easy;
10.[+E-Plus]=480,E-Plus Free&Easy;
10.[+Free&Easy]=480,E-Plus Free&Easy;
//
10.[188]=481,O2 LOOP;
10.[+O2 LOOP]=481,O2 LOOP;
10.[+O2]=481,O2 LOOP;
10.[+LOOP]=481,O2 LOOP;
//
10.[+431]=431,Premiere Flex;
10.[+Premiere Flex]=431,Premiere Flex;
10.[+Premiere]=431,Premiere Flex;
10.[+Flex]=431,Premiere Flex;
//
10.[189]=405,gobananas;
10.[+gobananas]=405,gobananas;
//
10.[180]=452,Paysafecard Blue;
10.[181]=452,Paysafecard Red;
10.[+Paysafecard]=452,Paysafecard;
//
// TEST PINPRINTING----------------
10.[349]=482,TEST PINPRINTING;
// GESCHENKGUTSCHEIN---------------
10.[806]=483,GESCHENKGUTSCHEIN;
//SCHLECKER CARDS------------------
10.[807]=484,SCHLECKER PREPAID;
10.[249]=486,smobil;
10.[250]=487,Schlecker Zusatz;
//VITALSANA-----------------------
10.[808]=485,VITALSANA;
//MOBILE CARDS--------------------
10.[246]=488,FONIC;
10.[206]=489,BILDmobil;
10.[205]=490,Blau.de;
10.[207]=491,Congstar;
10.[475]=492,Lebara Mobile;
10.[248]=493,Simyo;
10.[884]=494,Lycamobile;
10.[917]=495,GT mobile;
//AVS -----------------------------
10.[253]=496,AVS Gutscheinkarte;
//
// 220 TLAPA-KARTE---------------------
10.[231]=220,TLAPA-KARTE; 
//
//For the function READ CARD the recognition must be done by the card number
// MAESTRO ----------------------------
10.[+67]=1;
// COMFORT CARD -----------------------
10.[+564191]=442,Comfort Card;
// MASTERCARD -------------------------
10.[+5]=2;
// DINERS -----------------------------
10.[+36]=4;
// VISA -------------------------------
10.[+4]=5;
// AMEX -------------------------------
10.[+37]=6;
// JCB --------------------------------
10.[+35]=3;
//
// **********************************************************************************************************************************************
// Terminal type 11 (CH ACCARDA VIRTUAL CLIENT):
// The card recognition is hard coded.
// (The only possible card that can be used, is the ACCARDA Card)
// *******************************************************************************************************************************************
// ACCARDA ----------------------------
11.[+6004520306]=119,IKEA-CARD;
11.[+60045203]=119,Staedte-Card;
//
11.[+6004520698]=115,ACCARDA-Testcard;
11.[+60045206]=115,ACCARDA;
//
11.[115]=115,Giftcard;
//
// **********************************************************************************************************************************************
// Terminal type 12 (BE ATOS ORIGIN):
// The card recognition is based on a BIT MAP OF APPLICATION ID'S or on the BRAND ID (VIC 1.07/11).
// *******************************************************************************************************************************************
// VISA Electron ----------------------
12.[114]=10;
12.[1002]=10;
12.[visa electron]=10;
// VISA -------------------------------
12.[124]=5;
12.[2002]=5;
12.[visa]=5;
// VISA VPay---------------------------
12.[82]=10;
12.[+vpay]=10;
// JCB --------------------------------
12.[120]=3;
12.[2007]=3;
12.[jcb]=3;
// DINERS -----------------------------
12.[121]=4;
12.[2005]=4;
12.[diners]=4;
// AMEX -------------------------------
12.[122]=6;
12.[2004]=6;
12.[american express]=6;
// MASTERCARD -------------------------
12.[123]=2;
12.[2003]=2;
12.[mastercard]=2;
// Maestro ----------------------------
12.[127]=1;
12.[1009]=1;
12.[maestro]=1;
// Bancontact/Mister Cash -------------
12.[128]=500;
12.[1001]=500;
12.[bancontact/mca]=500;
12.[tina]=500,TINA;
12.[100]=500,TINA;
// PROTON -----------------------------
12.[125]=501;
12.[1010]=501;
12.[proton]=501;
// AURORA -----------------------------
12.[109]=502;
12.[3001]=502;
12.[aurora]=502;
// KADOZ ------------------------------
12.[64]=503;
12.[kadoz]=503;
//
// **********************************************************************************************************************************************
// Terminal type 13 (TREIBAUF SIMPATICO):
// Do not set a card recognition. Card type should be set in Simpatico itself.
// **********************************************************************************************************************************************
// SIMPATICO Cards --------------------
//
// **********************************************************************************************************************************************
// Terminal type 14 (CH PAYSYS):
// The card recognition is based on ISSUER NUMBER and CARD NUMBER.
// **********************************************************************************************************************************************
// MAESTRO ----------------------------
14.[7]=1;
14.[07]=1;
// MASTERCARD -------------------------
14.[2]=2;
14.[02]=2;
// JCB --------------------------------
14.[6]=3;
14.[06]=3;
// DINERS -----------------------------
14.[43]=4;
// VISA -------------------------------
14.[5]=5;
14.[05]=5;
//V PAY -------------------------------
14.[96]=11,V PAY;
// AMEX -------------------------------
14.[40]=6;
// MAESTRO CH -------------------------
14.[1]=100;
14.[01]=100;
// M-CARD -----------------------------
14.[22]=101;
// POSTCARD ---------------------------
14.[21]=102;
// BERN CARD --------------------------
14.[41]=103;
14.[42]=103;
14.[45]=103;
// MOEVENPICK -------------------------
14.[46]=108;
//LOKALKARTE (READ OVER USB-PORT)------
14.[80]=135;
// JELMOLI SHOPPING BONUS CARD --------
14.[81]=110;
// MYONE ------------------------------
14.[84]=111;
//COOP SUPERCARD PLUS MASTERCARD-------
14.[24]=116;
// POWERCARD --------------------------
14.[47]=117;
//COOP SUPERCARD PLUS VISA-------------
14.[26]=134;
//REKA  -------------------------------
14.[20]=120;
// BONCARD ----------------------------
14.[66]=160,BONARD POINTS;
14.[67]=161,BONCARD PAY;
//if recognition by Issuer Number fails, try by card number prefix
// MASTERCARD -------------------------
14.[+50]=2;
14.[+51]=2;
14.[+52]=2;
14.[+53]=2
14.[+54]=2;
14.[+55]=2;
// MAESTRO ----------------------------
14.[+67]=1;
14.[+56]=1;
14.[+57]=1;
14.[+58]=1;
14.[+59]=1;
// VISA -------------------------------
14.[+4]=5;
// DINERS -----------------------------
14.[+36]=4;
14.[+38]=4;
14.[+39]=4;
// AMEX -------------------------------
14.[+34]=6;
14.[+37]=6;
// JCB --------------------------------
14.[+35]=3;
//
// **********************************************************************************************************************************************
// Terminal type 15 (CH ADUNO OPTIMUM):
// The card recognition is based on the ISSUER NUMBER and Application-ID
// **********************************************************************************************************************************************
// MAESTRO ----------------------------
15.[7]=1;
15.[07]=1;
15.[+A0000000043060]=1;
15.[+A0000001570021]=1;
// MASTERCARD -------------------------
15.[2]=2;
15.[02]=2;
15.[+A0000000041010]=2;
15.[+A0000001570020]=2;
//M-Budget
15.[A0000000000008]=2;
// JCB -------------------------------
15.[6]=3;
15.[06]=3;
15.[+A0000000651010]=3;
15.[+A0000001570040]=3;
// DINERS -----------------------------
15.[43]=4;
15.[+A0000001884443]=4;
15.[+A0000001574443]=4;
15.[+A0000001570060]=4;
// VISA -------------------------------
15.[+A0000000031010]=5;
15.[+A0000001570030]=5;
// VISA ELECTRON-----------------------
15.[+A0000000032010]=10;
15.[+A0000001570031]=10;
//V PAY -------------------------------
15.[96]=11,V PAY;
15.[A0000000032020]=11,V PAY;
15.[A0000001574452]=11,V PAY;
// AMEX -------------------------------
15.[40]=6;
15.[+A00000002501]=6;
15.[+A0000001570010]=6;
15.[+A0000000291010]=6;
// CHINA UNION PAY --------------------
15.[9]=12,CHINA UNION PAY;
15.[09]=12,CHINA UNION PAY;
15.[A000000157446003]=12,CHINA UNION PAY;
15.[A000000157446004]=12,CHINA UNION PAY;
15.[A000000157446005]=12,CHINA UNION PAY;
15.[A000000157446006]=12,CHINA UNION PAY;
15.[A000000157446009]=12,CHINA UNION PAY;
// MAESTRO CH -------------------------
15.[1]=100;
15.[01]=100;
15.[+A0000000101030]=100;
15.[+A0000001570022]=100;
// M-CARD -----------------------------
15.[22]=101;
15.[A0000001570100]=101;
15.[A0000001574450]=101;
15.[A000000162010201]=101;
15.[m-card]=101;
// POSTFINANCE CARD -------------------
15.[21]=102;
15.[A0000001110101]=102;
15.[A0000001999999]=102;
15.[A0000001999998]=102;
15.[A0000001570051]=102;
15.[A0000001570050]=102;
15.[A0000001574445]=102;
15.[A0000001574446]=102;
15.[A0000001570110]=143,PostFinance Mobile Coup.;
15.[A0000001570111]=144,PostFinance Mobile Paym.;
// BERN-CARD --------------------------
15.[42]=103;
15.[+A0000001570107]=103;
// ZUERI-CARD -------------------------
15.[41]=104;
15.[+A0000001570106]=104;
// BASLER-CARD ------------------------
15.[45]=105;
15.[+A0000001570108]=105;
// CASH -------------------------------
15.[+A0000001570023]=106;
// PHARMACARD --------------------------
15.[55]=107;
15.[+A0000001570105]=107;
// MOEVENPICK -------------------------
15.[46]=108;
15.[+A0000001570102]=108;
// JELMOLI SHOPPING BONUS CARD --------
15.[+A0000001570103]=110;
15.[+A000000157010B]=110;
15.[+A000000003000375]=110;
15.[81]=110;
// JELMOLI PAYCARD --------------------
15.[A0000001574462]=137;
// MANOR CARD (MYONE) -----------------
15.[84]=111;
15.[+A0000001570104]=111;
15.[+A0000001570109]=111;
//COOP SUPERCARD PLUS MASTERCARD-------
15.[24]=116;
15.[A0000001574444]=116;
15.[A0000000049999C000020001]=116;
//COOP SUPERCARD PLUS VISA-------------
15.[26]=134;
15.[A0000001574458]=134;
15.[A00000000300037562]=134;
// POWERCARD (MFGroup)-----------------
15.[47]=117;
15.[+A000000157010D]=117;
// WIR --------------------------------
15.[85]=118;
15.[+A000000157010C]=118;
//REKA  -------------------------------
15.[+A000000157010E]=120;
15.[+D7560000010101]=120;
// JGIFT (JELMOLI)---------------------
15.[+A000000157444E]=122,J-Geschenkkarte;
// ADUNO CARDS --------------
15.[+A0000001574448]=123,Aduno Kundenkarte;
15.[+A0000001574449]=124,Swiss Bonus Card;
15.[+A000000157444A]=125,ABO Card;
15.[A000000157010F]=142,ADUNO TEST;
// MEDIAMARKT --------------
15.[+A0000001570109]=126,Mediamarkt Card;
// M-BUDGET ---------------------------- (M-Budget is not a Mastercard when accepted by a Migros Merchant)
15.[D7560000300101]=132,M-Budget;
// GIFT CARD (SIX)-----------------------
15.[A0000001574451]=133,Gift Card;
//SWISSCADEAU --------------------------
15.[A000000157445A]=136,SwissCadeau;
//KUNDENKARTE BONGENIE/GRIEDER ---------
15.[A000000157445E]=140,BonGenie/Grieder Card; 
//GIFT CARD (BILLAG) -------------------
15.[A000000157010A]=141,GIFT CARD BILLAG;
//ACCARDA STAEDTEKARTE -----------------
15.[A0000001570112]=115,ACCARDA STAEDTEKARTE;
// KUNDENKARTE OFAC ---------------------
15.[A0000001570113]=145,Kundenkarte OFAC;
// REINVEST SELECT AG COMPANY CARD -----
15.[A0000001574447]=146,REINVEST SELECT;
// KUNDENKARTE PKZ -----------------------
15.[A000000157445D]=147,KUNDENKARTE PKZ; 
// JUBIN CARD ----------------------------
15.[A000000157445F]=148,JUBIN CARD;
// INNOCARD -------------------------------
15.[A0000001574448]=149,INNOCARD KUNDENKARTE;
15.[A000000157444A]=150,ABO CARD;
15.[A0000001574459]=151,SWISS HAPPY CARD;
15.[A000000157445A]=152,SWISS CADEAU;
15.[A0000001574461]=153,DATA STANDARDS;
15.[A0000001574463]=154,SWISSBONUS+;
//SWISS BONUS CARD ------------------------
15.[A0000001574449]=155,SWISS BONUS CARD;
//GE MONEY BANK ---------------------------
15.[A000000157444B]=156,GE MONEY BANK;
15.[A000000157444F]=157,BARRACUDA TEMPCARD;
//MERGER CARD -----------------------------
15.[A000000157444C]=158,MERGER CARD;
15.[A000000157444D]=159,MERGER CARD 2;
// BANCOMAT LUXEMBOURG -------------------
15.[A0000001574453]=1000,BANCOMAT LUXEMBOURG;
// AURORA LUXEMBOURG ---------------------
15.[A0000001574454]=1001,AURORA LUXEMBOURG;
// BONCARD -------------------------------
15.[A0000001574455]=160,BONCARD POINTS;
15.[A000000157445B]=161,BONCARD PAY;
// FNAC ----------------------------------
15.[A0000001574456]=162,FNAC-KARTE;
// COMMIT CARD COMPANY CARD --------------
15.[A0000001574457]=163,COMMIT CARD;
// KUNDENKARTE LOEB ----------------------
15.[A000000157445C]=164,KUNDENKARTE LOEB;
//
// **********************************************************************************************************************************************
// Terminal type 16 (US VERIFONE PCCHARGE):
// The card recognition is based on pan
// **********************************************************************************************************************************************
// VISA -------------------------------
16.[+4]=5;
// MC - MASTERCARD --------------------
16.[+5]=2;
// AMEX -------------------------------
16.[+34]=6;
16.[+37]=6;
// JCB - Japanese Credit Banc ---------
16.[+3088]=3;
16.[+3089]=3;
16.[+309, -3095]=3;
16.[+311, -3110, 3112]=3;
16.[+3120]=3;
16.[+3158]=3;
16.[+3159]=3;
16.[+3337]=3;
16.[+3338]=3;
16.[+3339]=3;
16.[+334]=3;
16.[+3528]=3;
16.[+3529]=3;
16.[+353]=3;
16.[+354]=3;
16.[+355]=3;
16.[+356]=3;
16.[+357]=3;
16.[+358]=3;
// Disc - Discover --------------------
16.[+6011]=600;
// DCCB - Diners Club -----------------
16.[+36]=4;
16.[+38]=4;
16.[+300]=4;
16.[+301]=4;
16.[+302]=4;
16.[+303]=4;
16.[+304]=4;
16.[+305]=4;
// CBLN - Carte Blanche ---------------
16.[+389]=601;
// JAL- Japan Airlines ----------------
16.[+1800]=7;
16.[+2131]=7;
// ENRT - Enroute ---------------------
// ??? not yet supported
//
// **********************************************************************************************************************************************
// Terminal type 17 (CH SIX CARD SOLUTIONS VEZPLUS):
// The card recognition is based on the ISSUER NUMBER and Application-ID
// **********************************************************************************************************************************************
// MAESTRO ----------------------------
17.[7]=1;
17.[07]=1;
// MASTERCARD -------------------------
17.[2]=2;
17.[02]=2;
17.[44]=2;
//M-Budget
17.[25]=2;
// JCB --------------------------------
17.[6]=3;
17.[06]=3;
17.[49]=3;
// DINERS -----------------------------
17.[43]=4;
// VISA -------------------------------
17.[5]=5;
17.[05]=5;
17.[61]=5;
17.[62]=5;
//V PAY -------------------------------
17.[96]=11,V PAY;
// AMEX -------------------------------
17.[40]=6;
// CUP --------------------------------
17.[9]=12,CHINA UNION PAY;
17.[09]=12,CHINA UNION PAY;
// MAESTRO CH -------------------------
17.[1]=100;
17.[01]=100;
// M-CARD -----------------------------
17.[22]=101;
// POSTCARD ---------------------------
17.[21]=102;
// CASH -------------------------------
17.[8]=106;
17.[08]=106;
// JELMOLI BONUS SHOPPING CARD --------
//17.[+600451]=110;
17.[81]=110;
// JELMOLI PAYCARD --------------------
17.[a0000001574462]=137;
// MY ONE -----------------------------
17.[84]=111; 
// ORANGE -----------------------------
17.[75]=112;
// Sunrise ----------------------------
17.[76]=113;
// SWISSCOM ---------------------------
17.[77]=114;
//COOP SUPERCARD PLUS MASTERCARD-------
17.[24]=116;
//COOP SUPERCARD PLUS VISA-------------
17.[26]=134;
// POWERCARD --------------------------
17.[87]=117;
// WIR --------------------------------
17.[50]=118; 
// IKEA-CARD --------------------------
17.[+6004520306]=119,IKEA-CARD   ;
17.[91]=119,IKEA-CARD   ;
17.[63]=119,IKEA-CARD   ;
//REKA  -------------------------------
17.[90]=120;
// STAEDTECARD ------------------------
17.[41]=121;
17.[+600452]=121;
// JGIFT (JELMOLI)---------------------
17.[72]=122;
// YALLO ------------------------------
17.[73]=127,Yallo;
// COOP MOBILE ------------------------
17.[78]=128,Coop Mobile;
// PHONECARD ---------------------------
17.[79]=129,phoneCard;
// ORANGECLICK.CH ----------------------
17.[80]=130,orangeclick.ch;
// M-BUDGET MOBILE ---------------------
17.[82]=131,M-Budget Mobile;
// GIFTCARD (SIX)-----------------------
17.[97]=133,GiftCard;
//SWISSCADEAU
17.[A000000157445A]=136,SwissCadeau;
// BANCOMAT LUXEMBOURG ----------------
17.[30]=1000,BANCOMAT LUXEMBOURG;
17.[A0000001574453]=1000,BANCOMAT LUXEMBOURG;
// AURORA LUXEMBOURG ------------------
17.[31]=1001,AURORA LUXEMBOURG;
17.[A0000001574454]=1001,AURORA LUXEMBOURG;
//KUNDENKARTE BONGENIE/GRIEDER ---------
17.[A000000157445E]=140,BonGenie/Grieder Card; 
//BONCARD ------------------------------
17.[66]=160,BONARD POINTS;
17.[67]=161,BONCARD PAY;
//
// **********************************************************************************************************************************************
// Terminal type 18 (DE HYPERCOM/THALES EFT Library (MCSSoft)):
// The card recognition is based on the ISSUER NUMBER and PAN
// **********************************************************************************************************************************************
// MAESTRO_DE -------------------------
18.[0]=401;
18.[+672]=401;
// MAESTRO ----------------------------
18.[21]=1;
18.[+56]=1;
18.[+57]=1;
18.[+58]=1;
18.[+59]=1;
18.[+6]=1;
// other cards have the Pepper default values and are handled internally
//
// **********************************************************************************************************************************************
// Terminal type 20 (CH INGENICO 5100): 
// The card recognition is based on the AID
// **********************************************************************************************************************************************
// MAESTRO ------------------------
20.[+A0000000043060]=1;   //this AID is ambiguous (could also be Maestro-CH)
20.[+A0000001570021]=1;
// MASTERCARD ---------------------
20.[+A0000000041010]=2;
20.[+A0000001570020]=2;
//M-Budget -----------------------
20.[A0000000000008]=2;
// JCB ---------------------------
20.[+A0000000651010]=3;
20.[+A0000001570040]=3;
// DINERS ------------------------
20.[+A0000001884443]=4;
20.[+A0000001574443]=4;
20.[+A0000001570060]=4;
// VISA --------------------------
20.[+A0000000031010]=5;
20.[+A0000001570030]=5;
// VISA ELECTRON-----------------------
20.[+A0000000032010]=10;
20.[+A0000001570031]=10;
//V PAY -------------------------------
20.[+A0000000032020]=11,V PAY;
// AMERICAN EXPRESS --------------
20.[+A0000001570010]=6;
20.[+A00000002501]=6;
20.[+A0000000291010]=6;
// CHINA UNION PAY --------------------
20.[A000000157446003]=12,CHINA UNION PAY;
20.[A000000157446004]=12,CHINA UNION PAY;
20.[A000000157446005]=12,CHINA UNION PAY;
20.[A000000157446006]=12,CHINA UNION PAY;
20.[A000000157446009]=12,CHINA UNION PAY;
// MAESTRO CH --------------------
20.[+A0000000101030]=100;
20.[+A0000001570022]=100;
// M-CARD ------------------------
20.[A0000001570100]=101;
20.[A0000001574450]=101;
// POSTCARD
20.[+A0000001110101]=102;
20.[+A0000001999999]=102;
20.[+A0000001999998]=102;
20.[+A0000001570051]=102;
20.[+A0000001570050]=102;
20.[+A0000001574445]=102;
20.[+A0000001574446]=102;
// BERN CARD --------------------
20.[+A0000001570107]=103;
// ZUERI CARD -------------------
20.[+A0000001570106]=104;
// BASLER CARD ------------------
20.[+A0000001570108]=105;
// CASH -------------------------
20.[+A0000001570023]=106;
// PHARMACARD --------------------
20.[+A0000001570105]=107;
// MOEVENPICK -------------------
20.[+A0000001570102]=108;
// JELMOLI SHOPPING BONUS CARD --
20.[+A0000001570103]=110;
20.[+A000000157010B]=110;
20.[+A000000003000375]=110;
// JELMOLI PAYCARD --------------------
20.[a0000001574462]=137;
// MY ONE -----------------------
20.[+A0000001570104]=111;
//COOP SUPERCARD PLUS MASTERCARD-------
20.[A0000001574444]=116;
20.[A0000000049999C000020001]=116;
//COOP SUPERCARD PLUS VISA-------------
20.[A0000001574458]=134;
20.[A00000000300037562]=134;
// POWER CARD -------------------
20.[+A000000157010D]=117;
// WIR --------------------------
20.[+A000000157010C]=118;
//REKA  -------------------------------
20.[+A000000157010E]=120;
20.[+D7560000010101]=120;
// JGIFT (JELMOLI)---------------------
20.[+A000000157444E]=122,J-Geschenkkarte;
// MEDIAMARKT --------------
20.[+A0000001570109]=126,Mediamarkt Card;
// M-BUDGET ---------------------------- (M-Budget is not a Mastercard when accepted by a Migros Merchant)
20.[D7560000300101]=132,M-Budget;
//SWISSCADEAU --------------------------
20.[A000000157445A]=136,SwissCadeau;
//KUNDENKARTE BONGENIE/GRIEDER ---------
20.[A000000157445E]=140,BonGenie/Grieder Card; 
//BONCARD ------------------------------
20.[A0000001574455]=160,BONARD POINTS;
20.[A000000157445B]=161,BONCARD PAY;
//
// **********************************************************************************************************************************************
// Terminal type 21 (AT/LU SIX CARD SOLUTIONS MPD):
// The card recognition is based on ISSUER NUMBER, Card Name and AID 
// **********************************************************************************************************************************************
// where Issuer-Nbr exist do not use AID, rely on Issuer-Nbr from terminal
// MAESTRO ----------------------------
21.[7]=1;
21.[07]=1;
// MASTERCARD -------------------------
21.[2]=2;
21.[02]=2;
//M-Budget
21.[25]=2;
// JCB --------------------------------
21.[6]=3;
21.[06]=3;
// DINERS -----------------------------
21.[43]=4;
// VISA -------------------------------
//21.[5]=5;  //DO NOT USE BRAND-ID 5 because of mix up with Bancomat Luxembourg
//21.[05]=5;
21.[+A0000000031010]=5;
21.[+A0000001570030]=5;
// VISA ELECTRON-----------------------
21.[+A0000000032010]=10,VISA ELECTRON;
21.[+A0000001570031]=10,VISA ELECTRON;
//V PAY -------------------------------
21.[96]=11,V PAY;
21.[A0000000032020]=11,V PAY;
21.[A0000001574452]=11,V PAY;
// AMEX -------------------------------
21.[40]=6;
// BANCOMAT LUXEMBOURG ----------------
21.[30]=1000,BANCOMAT LUXEMBOURG;
21.[+D44200002542414E]=1000,BANCOMAT LUXEMBOURG;
// AURORA LUXEMBOURG ------------------
21.[31]=1001,AURORA LUXEMBOURG;
// MAESTRO CH -------------------------
21.[1]=100;
21.[01]=100;
// CUP --------------------------------
21.[9]=12,CHINA UNION PAY;
21.[09]=12,CHINA UNION PAY;
// BONCARD ----------------------------
21.[66]=160,BONARD POINTS;
21.[67]=161,BONCARD PAY;
//
// **********************************************************************************************************************************************
// Terminal type 22 (SI B+S Card Services CCV ST-4000 ZVT):
// The card recognition is based on CARD TYPE (Kartenart BMP 8A) and PAYMENT TYPE (Zahlart BMP 19).
// **********************************************************************************************************************************************
// CHINA UNION PAY ---------------------
22.[198]=12,CHINA UNION PAY;
//-----------------  new card types TA 7.0 --------------
// girocard ---------------------------
22.[5]=9,GIROCARD;
// EAPS -------------------------------
22.[7]=8,EAPS;
// girocard deutsche Lastschrift ------
22.[9]=409,GIROCARD DE LASTSCHRIFT;
// VISA electron ----------------------
22.[11]=10,VISA ELECTRON;
// V PAY ------------------------------
22.[13]=11,V PAY;
//-------------- end new card types TA 7.0 -------------
// MAESTRO ----------------------------
22.[46]=1;
// MASTERCARD -------------------------
22.[6]=2;
// DINERS -----------------------------
22.[12]=4;
// VISA -------------------------------
22.[10]=5;
// AMEX -------------------------------
22.[8]=6;
// JCB --------------------------------
22.[14]=3;
// INTERCARD GUTSCHEINKARTE------------
22.[240]=440,IC-Gutscheinkarte;
// 
//For the function READ CARD the recognition must be done by the card number
// MAESTRO ----------------------------
22.[+67]=1;
// MASTERCARD -------------------------
22.[+5]=2;
// DINERS -----------------------------
22.[+36]=4;
// VISA -------------------------------
22.[+4]=5;
// AMEX -------------------------------
22.[+37]=6;
// JCB --------------------------------
22.[+35]=3;
// **********************************************************************************************************************************************
// Terminal type 23 (CZ INGENICO, CESKA SPORITELNA, POS-ECR interface Version 2.3):
// The card recognition is based on CARD ISSUER ID (CARD_TYPE).
// **********************************************************************************************************************************************
// MAESTRO ----------------------------
23.[05]=1,CS and others;
// MASTERCARD -------------------------
23.[01]=2,MasterCard ;
// DINERS -----------------------------
23.[02]=4,Diners;
// VISA -------------------------------
23.[00]=5,VISA;
// AMEX -------------------------------
23.[04]=6,AmEx;
// JCB --------------------------------
23.[03]=3,JCB;
//
// **********************************************************************************************************************************************
// Terminal type 24 (FR CONCERT CAISSE EURO V. 2.0):
// The card recognition is based on the EMETTEUER and the CARD NUMBER PREFIX.
// **********************************************************************************************************************************************
//
//China Union Pay Natixis/China Union Pay 
24.[+620]=12,CHINA UNION PAY;
24.[+621]=12,CHINA UNION PAY;
24.[+622]=12,CHINA UNION PAY;
24.[+623]=12,CHINA UNION PAY;
24.[+624]=12,CHINA UNION PAY;
24.[+625]=12,CHINA UNION PAY;
24.[+456351]=12,CHINA UNION PAY;
24.[+602969]=12,CHINA UNION PAY;
24.[+603367]=12,CHINA UNION PAY;

6200-6250 (China UnionPay)
// MASTERCARD ---------------------------
24.[+50]=2,MASTERCARD;
24.[+51]=2,MASTERCARD;
24.[+52]=2,MASTERCARD;
24.[+53]=2,MASTERCARD
24.[+54]=2,MASTERCARD;
24.[+55]=2,MASTERCARD;
// MAESTRO ------------------------------
24.[+67]=1,MAESTRO;
24.[+56]=1,MAESTRO;
24.[+57]=1,MAESTRO;
24.[+58]=1,MAESTRO;
24.[+59]=1,MAESTRO;
// VISA ---------------------------------
24.[+4]=5,VISA;
// DINERS -------------------------------
24.[6]=4,DINERS CLUB FRANCE;
24.[+36]=4,DINERS CLUB FRANCE;
24.[+38]=4,DINERS CLUB FRANCE;
24.[+39]=4,DINERS CLUB FRANCE;
// AMEX ---------------------------------
24.[2]=6,AMERICAN EXPRESS;
24.[+34]=6,AMERICAN EXPRESS;
24.[+37]=6,AMERICAN EXPRESS;
// JCB ----------------------------------
24.[9]=3,JCB;
24.[+35]=3,JCB;
//Reflexe/Aurore - prot. CETNCB CETDIS---
24.[3]=911,AURORE;
//CETELEM -------------------------------
24.[4]=931,CETELM;
//COFINOGA ------------------------------
24.[5]=908,COFINOGA; 
//Pass piste/Pass EMV -------------------
24.[7]=923,PASS;
//Pluriel - FranFinance -----------------
24.[8]=915,FRANFINANCE;
//ACCORD --------------------------------
24.[A]=901,ACCORD;
//Chque --------------------------------
24.[C]=909,CHEQUE;
//Finaref -------------------------------
24.[F]=917,FINAREF; 
//Modeus --------------------------------
24.[M]=932,MODEUS;
//Carte Pinault Printemps Redoute -------
24.[P]=933,PINAULT PRINTEMPS RED.;
//
// **********************************************************************************************************************************************
// Terminal type 25 (DE INGENICO U32 ZVT)
// The card recognition is based on CARD TYPE (Kartenart BMP 8A) and PAYMENT TYPE (Zahlart BMP 19).
// **********************************************************************************************************************************************
// CHINA UNION PAY ---------------------
25.[198]=12,CHINA UNION PAY;
//-----------------  new card types TA 7.0 --------------
// girocard ---------------------------
25.[5]=9,GIROCARD;
// EAPS -------------------------------
25.[7]=8,EAPS;
// girocard deutsche Lastschrift ------
25.[9]=409,GIROCARD DE LASTSCHRIFT;
// VISA electron ----------------------
25.[11]=10,VISA ELECTRON;
// V PAY ------------------------------
25.[13]=11,V PAY;
// AUSTRIA CARD -----------------------
25.[217]=217,Austria Card;
//-------------- end new card types TA 7.0 -------------
// MAESTRO ----------------------------
25.[46]=1;
// MASTERCARD -------------------------
25.[6]=2;
// DINERS -----------------------------
25.[12]=4;
// VISA -------------------------------
25.[10]=5;
// AMEX -------------------------------
25.[8]=6;
// JCB --------------------------------
25.[14]=3;
// MAESTRO DE / ELV -------------------
25.[2ELV]=410;
// MAESTRO DE / OLV -------------------
25.[2OLV]=411;
// MAESTRO DE / ec-CASH ---------------
25.[2CASH]=412;
// MAESTRO DE / default ---------------
25.[2]=401;
// GELDKARTE --------------------------
25.[30]=402;
// IKEA FAMILY PLUS -------------------
25.[76]=403;
// HORNBACH Profi ---------------------
25.[137]=420,HORNBACH Profi;
// HORNBACH Welt ----------------------
25.[138]=421,HORNBACH Welt;
// HORNBACH Welt ----------------------
25.[157]=422,HORNBACH Gutscheinkarte; 
// INTERCARD GUTSCHEINKARTE------------
25.[240]=440,IC-Gutscheinkarte;
//-------------------------------------
// Comfort Card -----------------------
25.[42]=442,Comfort Card;
// Breuninger--------------------------
25.[38]=438,Breuninger;
//
// Prepaid Phone Cards ----------------
25.[+414]=414,AnniCard;
25.[+AnniCard]=414,AnniCard;
//
25.[212]=441,T-D1 XTRA;
25.[+T-D1 XTRA]=441,T-D1 XTRA;
25.[+T-D1]=441,T-D1 XTRA;
25.[+XTRA]=441,T-D1 XTRA;
//
25.[191]=479,Vodafone CallYa;
25.[+Vodafone CallYa]=479,Vodafone CallYa;
25.[+Vodafone]=479,Vodafone CallYa;
25.[+CallYa]=479,Vodafone CallYa;
//
25.[+80]=480,E-Plus Free&Easy;
25.[+E-Plus Free&Easy]=480,E-Plus Free&Easy;
25.[+E-Plus]=480,E-Plus Free&Easy;
25.[+Free&Easy]=480,E-Plus Free&Easy;
//
25.[188]=481,O2 LOOP;
25.[+O2 LOOP]=481,O2 LOOP;
25.[+O2]=481,O2 LOOP;
25.[+LOOP]=481,O2 LOOP;
//
25.[+431]=431,Premiere Flex;
25.[+Premiere Flex]=431,Premiere Flex;
25.[+Premiere]=431,Premiere Flex;
25.[+Flex]=431,Premiere Flex;
//
25.[189]=405,gobananas;
25.[+gobananas]=405,gobananas;
//
25.[+352]=452,Paysafecard;
25.[+Paysafecard]=452,Paysafecard;
//
// TEST PINPRINTING----------------
25.[349]=482,TEST PINPRINTING;
// GESCHENKGUTSCHEIN---------------
25.[806]=483,GESCHENKGUTSCHEIN;
//SCHLECKER CARDS------------------
25.[807]=484,SCHLECKER PREPAID;
25.[249]=486,smobil;
25.[250]=487,Schlecker Zusatz;
//VITALSANA-----------------------
25.[808]=485,VITALSANA;
//MOBILE CARDS--------------------
25.[246]=488,FONIC;
25.[206]=489,BILDmobil;
25.[205]=490,Blau.de;
25.[207]=491,Congstar;
25.[475]=492,Lebara Mobile;
25.[248]=493,Simyo;
25.[884]=494,Lycamobile;
25.[917]=495,GT mobile;
//AVS -----------------------------
25.[253]=496,AVS Gutscheinkarte;
//
//For the function READ CARD the recognition must be done by the card number
// MAESTRO ----------------------------
25.[+67]=1;
// COMFORT CARD -----------------------
25.[+564191]=442,Comfort Card;
// MASTERCARD -------------------------
25.[+5]=2;
// DINERS -----------------------------
25.[+36]=4;
// VISA -------------------------------
25.[+4]=5;
// AMEX -------------------------------
25.[+37]=6;
// JCB --------------------------------
25.[+35]=3;
// **********************************************************************************************************************************************
// Terminal type 25 (DE INGENICO U32) >>>>>> Atos Card-IDs <<<<<<
// The card recognition is based on CARD TYPE (Kartenart BMP 8A) and PAYMENT TYPE (Zahlart BMP 19).
// **********************************************************************************************************************************************
// MAESTRO ----------------------------
//25.[21]=1;
// MASTERCARD -------------------------
//25.[1]=2;
// DINERS -----------------------------
//25.[4]=4;
// VISA -------------------------------
//25.[3]=5;
// AMEX -------------------------------
//25.[2]=6;
// MAESTRO DE / ELV -------------------
//25.[0ELV]=410;
// MAESTRO DE / OLV -------------------
//25.[0OLV]=411;
// MAESTRO DE / ec-CASH ---------------
//25.[0CASH]=412;
// MAESTRO DE / default ---------------
//25.[0]=401;
// GELDKARTE --------------------------
//25.[30]=402;
//
//For the function READ CARD the recognition must be done by the card number
// MAESTRO ----------------------------
//25.[+67]=1;
// COMFORT CARD -----------------------
//25.[+564191]=442,Comfort Card;
// MASTERCARD -------------------------
//25.[+5]=2;
// DINERS -----------------------------
//25.[+36]=4;
// VISA -------------------------------
//25.[+4]=5;
// AMEX -------------------------------
//25.[+37]=6;
// JCB --------------------------------
//25.[+35]=3;
// **********************************************************************************************************************************************
// Terminal type 26 (CH ADUNO VERDI):
// The card recognition is based on the ISSUER NUMBER or Application-ID
// **********************************************************************************************************************************************
// MAESTRO ----------------------------
26.[7]=1;
26.[07]=1;
26.[+A0000000043060]=1;
26.[+A0000001570021]=1;
// MASTERCARD -------------------------
26.[2]=2;
26.[02]=2;
26.[+A0000000041010]=2;
26.[+A0000001570020]=2;
//M-Budget
26.[A0000000000008]=2;
// JCB -------------------------------
26.[6]=3;
26.[06]=3;
26.[+A0000000651010]=3;
26.[+A0000001570040]=3;
// DINERS -----------------------------
26.[43]=4;
26.[+A0000001884443]=4;
26.[+A0000001574443]=4;
26.[+A0000001570060]=4;
// VISA -------------------------------
26.[+A0000000031010]=5;
26.[+A0000001570030]=5;
// VISA ELECTRON-----------------------
26.[+A0000000032010]=10;
26.[+A0000001570031]=10;
//V PAY -------------------------------
26.[96]=11,V PAY;
26.[A0000000032020]=11,V PAY;
26.[A0000001574452]=11,V PAY;
// AMEX -------------------------------
26.[40]=6;
26.[+A00000002501]=6;
26.[+A0000001570010]=6;
26.[+A0000000291010]=6;
// CHINA UNION PAY --------------------
26.[9]=12,CHINA UNION PAY;
26.[09]=12,CHINA UNION PAY;
26.[A000000157446003]=12,CHINA UNION PAY;
26.[A000000157446004]=12,CHINA UNION PAY;
26.[A000000157446005]=12,CHINA UNION PAY;
26.[A000000157446006]=12,CHINA UNION PAY;
26.[A000000157446009]=12,CHINA UNION PAY;
// MAESTRO CH -------------------------
26.[1]=100;
26.[01]=100;
26.[+A0000000101030]=100;
26.[+A0000001570022]=100;
// M-CARD -----------------------------
26.[22]=101;
26.[A0000001570100]=101;
26.[A0000001574450]=101;
26.[A000000162010201]=101;
26.[m-card]=101;
// POSTFINANCE CARD -------------------
26.[21]=102;
26.[A0000001110101]=102;
26.[A0000001999999]=102;
26.[A0000001999998]=102;
26.[A0000001570051]=102;
26.[A0000001570050]=102;
26.[A0000001574445]=102;
26.[A0000001574446]=102;
26.[A0000001570110]=143,PostFinance Mobile Coup.;
26.[A0000001570111]=144,PostFinance Mobile Paym.;
// BERN-CARD --------------------------
26.[42]=103;
26.[+A0000001570107]=103;
// ZUERI-CARD -------------------------
26.[41]=104;
26.[+A0000001570106]=104;
// BASLER-CARD ------------------------
26.[45]=105;
26.[+A0000001570108]=105;
// CASH -------------------------------
26.[+A0000001570023]=106;
// PHARMACARD --------------------------
26.[55]=107;
26.[+A0000001570105]=107;
// MOEVENPICK -------------------------
26.[46]=108;
26.[+A0000001570102]=108;
// JELMOLI SHOPPING BONUS CARD --------
26.[+A0000001570103]=110;
26.[+A000000157010B]=110;
26.[+A000000003000375]=110;
26.[81]=110;
// JELMOLI PAYCARD --------------------
26.[A0000001574462]=137;
// MANOR CARD (MYONE) -----------------
26.[84]=111;
26.[+A0000001570104]=111;
26.[+A0000001570109]=111;
//COOP SUPERCARD PLUS MASTERCARD-------
26.[24]=116;
26.[A0000001574444]=116;
26.[A0000000049999C000020001]=116;
//COOP SUPERCARD PLUS VISA-------------
26.[26]=134;
26.[A0000001574458]=134;
26.[A00000000300037562]=134;
// POWERCARD (MFGroup)-----------------
26.[47]=117;
26.[+A000000157010D]=117;
// WIR --------------------------------
26.[85]=118;
26.[+A000000157010C]=118;
//REKA  -------------------------------
26.[+A000000157010E]=120;
26.[+D7560000010101]=120;
// JGIFT (JELMOLI)---------------------
26.[+A000000157444E]=122,J-Geschenkkarte;
// ADUNO CARDS --------------
26.[+A0000001574448]=123,Aduno Kundenkarte;
26.[+A0000001574449]=124,Swiss Bonus Card;
26.[+A000000157444A]=125,ABO Card;
26.[A000000157010F]=142,ADUNO TEST;
// MEDIAMARKT --------------
26.[+A0000001570109]=126,Mediamarkt Card;
// M-BUDGET ---------------------------- (M-Budget is not a Mastercard when accepted by a Migros Merchant)
26.[D7560000300101]=132,M-Budget;
// GIFT CARD (SIX)-----------------------
26.[A0000001574451]=133,Gift Card;
//SWISSCADEAU --------------------------
26.[A000000157445A]=136,SwissCadeau;
//KUNDENKARTE BONGENIE/GRIEDER ---------
26.[A000000157445E]=140,BonGenie/Grieder Card; 
//GIFT CARD (BILLAG) -------------------
26.[A000000157010A]=141,GIFT CARD BILLAG;
//ACCARDA STAEDTEKARTE -----------------
26.[A0000001570112]=115,ACCARDA STAEDTEKARTE;
// KUNDENKARTE OFAC ---------------------
26.[A0000001570113]=145,Kundenkarte OFAC;
// REINVEST SELECT AG COMPANY CARD -----
26.[A0000001574447]=146,REINVEST SELECT;
// KUNDENKARTE PKZ -----------------------
26.[A000000157445D]=147,KUNDENKARTE PKZ; 
// JUBIN CARD ----------------------------
26.[A000000157445F]=148,JUBIN CARD;
// INNOCARD -------------------------------
26.[A0000001574448]=149,INNOCARD KUNDENKARTE;
26.[A000000157444A]=150,ABO CARD;
26.[A0000001574459]=151,SWISS HAPPY CARD;
26.[A000000157445A]=152,SWISS CADEAU;
26.[A0000001574461]=153,DATA STANDARDS;
26.[A0000001574463]=154,SWISSBONUS+;
//SWISS BONUS CARD ------------------------
26.[A0000001574449]=155,SWISS BONUS CARD;
//GE MONEY BANK ---------------------------
26.[A000000157444B]=156,GE MONEY BANK;
26.[A000000157444F]=157,BARRACUDA TEMPCARD;
//MERGER CARD -----------------------------
26.[A000000157444C]=158,MERGER CARD;
26.[A000000157444D]=159,MERGER CARD 2;
// BANCOMAT LUXEMBOURG -------------------
26.[A0000001574453]=1000,BANCOMAT LUXEMBOURG;
// AURORA LUXEMBOURG ---------------------
26.[A0000001574454]=1001,AURORA LUXEMBOURG;
// BONCARD -------------------------------
26.[A0000001574455]=160,BONCARD POINTS;
26.[A000000157445B]=161,BONCARD PAY;
// FNAC ----------------------------------
26.[A0000001574456]=162,FNAC-KARTE;
// COMMIT CARD COMPANY CARD --------------
26.[A0000001574457]=163,COMMIT CARD;
// KUNDENKARTE LOEB ----------------------
26.[A000000157445C]=164,KUNDENKARTE LOEB;
//
// **********************************************************************************************************************************************
// Terminal type 27 (CH ADUNO BLADE):
// The card recognition is based on the ISSUER NUMBER and Application-ID
// **********************************************************************************************************************************************
// MAESTRO ----------------------------
27.[7]=1;
27.[07]=1;
27.[+A0000000043060]=1;
27.[+A0000001570021]=1;
// MASTERCARD -------------------------
27.[2]=2;
27.[02]=2;
27.[+A0000000041010]=2;
27.[+A0000001570020]=2;
//M-Budget
27.[A0000000000008]=2;
// JCB -------------------------------
27.[6]=3;
27.[06]=3;
27.[+A0000000651010]=3;
27.[+A0000001570040]=3;
// DINERS -----------------------------
27.[43]=4;
27.[+A0000001884443]=4;
27.[+A0000001574443]=4;
27.[+A0000001570060]=4;
// VISA -------------------------------
27.[+A0000000031010]=5;
27.[+A0000001570030]=5;
// VISA ELECTRON-----------------------
27.[+A0000000032010]=10;
27.[+A0000001570031]=10;
//V PAY -------------------------------
27.[96]=11,V PAY;
27.[A0000000032020]=11,V PAY;
27.[A0000001574452]=11,V PAY;
// AMEX -------------------------------
27.[40]=6;
27.[+A00000002501]=6;
27.[+A0000001570010]=6;
27.[+A0000000291010]=6;
// CHINA UNION PAY --------------------
27.[9]=12,CHINA UNION PAY;
27.[09]=12,CHINA UNION PAY;
27.[A000000157446003]=12,CHINA UNION PAY;
27.[A000000157446004]=12,CHINA UNION PAY;
27.[A000000157446005]=12,CHINA UNION PAY;
27.[A000000157446006]=12,CHINA UNION PAY;
27.[A000000157446009]=12,CHINA UNION PAY;
// MAESTRO CH -------------------------
27.[1]=100;
27.[01]=100;
27.[+A0000000101030]=100;
27.[+A0000001570022]=100;
// M-CARD -----------------------------
27.[22]=101;
27.[A0000001570100]=101;
27.[A0000001574450]=101;
27.[A000000162010201]=101;
27.[m-card]=101;
// POSTFINANCE CARD -------------------
27.[21]=102;
27.[A0000001110101]=102;
27.[A0000001999999]=102;
27.[A0000001999998]=102;
27.[A0000001570051]=102;
27.[A0000001570050]=102;
27.[A0000001574445]=102;
27.[A0000001574446]=102;
27.[A0000001570110]=143,PostFinance Mobile Coup.;
27.[A0000001570111]=144,PostFinance Mobile Paym.;
// BERN-CARD --------------------------
27.[42]=103;
27.[+A0000001570107]=103;
// ZUERI-CARD -------------------------
27.[41]=104;
27.[+A0000001570106]=104;
// BASLER-CARD ------------------------
27.[45]=105;
27.[+A0000001570108]=105;
// CASH -------------------------------
27.[+A0000001570023]=106;
// PHARMACARD --------------------------
27.[55]=107;
27.[+A0000001570105]=107;
// MOEVENPICK -------------------------
27.[46]=108;
27.[+A0000001570102]=108;
// JELMOLI SHOPPING BONUS CARD --------
27.[+A0000001570103]=110;
27.[+A000000157010B]=110;
27.[+A000000003000375]=110;
27.[81]=110;
// JELMOLI PAYCARD --------------------
27.[A0000001574462]=137;
// MANOR CARD (MYONE) -----------------
27.[84]=111;
27.[+A0000001570104]=111;
27.[+A0000001570109]=111;
//COOP SUPERCARD PLUS MASTERCARD-------
27.[24]=116;
27.[A0000001574444]=116;
27.[A0000000049999C000020001]=116;
//COOP SUPERCARD PLUS VISA-------------
27.[26]=134;
27.[A0000001574458]=134;
27.[A00000000300037562]=134;
// POWERCARD (MFGroup)-----------------
27.[47]=117;
27.[+A000000157010D]=117;
// WIR --------------------------------
27.[85]=118;
27.[+A000000157010C]=118;
//REKA  -------------------------------
27.[+A000000157010E]=120;
27.[+D7560000010101]=120;
// JGIFT (JELMOLI)---------------------
27.[+A000000157444E]=122,J-Geschenkkarte;
// ADUNO CARDS --------------
27.[+A0000001574448]=123,Aduno Kundenkarte;
27.[+A0000001574449]=124,Swiss Bonus Card;
27.[+A000000157444A]=125,ABO Card;
27.[A000000157010F]=142,ADUNO TEST;
// MEDIAMARKT --------------
27.[+A0000001570109]=126,Mediamarkt Card;
// M-BUDGET ---------------------------- (M-Budget is not a Mastercard when accepted by a Migros Merchant)
27.[D7560000300101]=132,M-Budget;
// GIFT CARD (SIX)-----------------------
27.[A0000001574451]=133,Gift Card;
//SWISSCADEAU --------------------------
27.[A000000157445A]=136,SwissCadeau;
//KUNDENKARTE BONGENIE/GRIEDER ---------
27.[A000000157445E]=140,BonGenie/Grieder Card; 
//GIFT CARD (BILLAG) -------------------
27.[A000000157010A]=141,GIFT CARD BILLAG;
//ACCARDA STAEDTEKARTE -----------------
27.[A0000001570112]=115,ACCARDA STAEDTEKARTE;
// KUNDENKARTE OFAC ---------------------
27.[A0000001570113]=145,Kundenkarte OFAC;
// REINVEST SELECT AG COMPANY CARD -----
27.[A0000001574447]=146,REINVEST SELECT;
// KUNDENKARTE PKZ -----------------------
27.[A000000157445D]=147,KUNDENKARTE PKZ; 
// JUBIN CARD ----------------------------
27.[A000000157445F]=148,JUBIN CARD;
// INNOCARD -------------------------------
27.[A0000001574448]=149,INNOCARD KUNDENKARTE;
27.[A000000157444A]=150,ABO CARD;
27.[A0000001574459]=151,SWISS HAPPY CARD;
27.[A000000157445A]=152,SWISS CADEAU;
27.[A0000001574461]=153,DATA STANDARDS;
27.[A0000001574463]=154,SWISSBONUS+;
//SWISS BONUS CARD ------------------------
27.[A0000001574449]=155,SWISS BONUS CARD;
//GE MONEY BANK ---------------------------
27.[A000000157444B]=156,GE MONEY BANK;
27.[A000000157444F]=157,BARRACUDA TEMPCARD;
//MERGER CARD -----------------------------
27.[A000000157444C]=158,MERGER CARD;
27.[A000000157444D]=159,MERGER CARD 2;
// BANCOMAT LUXEMBOURG -------------------
27.[A0000001574453]=1000,BANCOMAT LUXEMBOURG;
// AURORA LUXEMBOURG ---------------------
27.[A0000001574454]=1001,AURORA LUXEMBOURG;
// BONCARD -------------------------------
27.[A0000001574455]=160,BONARD POINTS;
27.[A000000157445B]=161,BONCARD PAY;
// FNAC ----------------------------------
27.[A0000001574456]=162,FNAC-KARTE;
// COMMIT CARD COMPANY CARD --------------
27.[A0000001574457]=163,COMMIT CARD;
// KUNDENKARTE LOEB ----------------------
27.[A000000157445C]=164,KUNDENKARTE LOEB;
//
// **********************************************************************************************************************************************
// Terminal type 28 (NL BANKSYS / VIC Standard oriented C-ZAM/SMASH & C-ZAM/SPIN 1.06A (Draft)):
// The card recognition is based on mod_name (Bit 180).
// *******************************************************************************************************************************************
// VISA -------------------------------
28.[VISA]=5;
28.[Visa]=5;
28.[V Pay]=11;
// JCB --------------------------------
28.[JCB]=3;
// DINERS -----------------------------
28.[DINERS]=4;
28.[Diners]=4;
// AMEX -------------------------------
28.[AMEX]=6;
// MASTERCARD -------------------------
28.[ECMC]=2;
28.[MasterCard]=2;
// Maestro ----------------------------
28.[MAES]=1;
28.[Maestro]=1;
// Bancontact/Mister Cash -------------
28.[BANK]=700;
// Postbank ---------------------------
28.[GIRO]=9;
//EPWS --------------------------------
28.[EPWS]=702;   
//CUP ---------------------------------
28.[CUP]=12;
//CMFC --------------------------------
28.[CMFC]=704
//PRLI --------------------------------
28.[PRLI]=705;
//Basic Card --------------------------
28.[Basic Card]=706;
//Schoenenbon -------------------------
28.[Schoenenbon]=707;
//Fashion Card ------------------------
28.[Fashion Card]=708;
//CCV Card ----------------------------
28.[CCV Card]=709;
//Yourgift ----------------------------
28.[Yourgift H&G]=710;
28.[Yourgift G&M]=711;
28.[Yourgift M&M]=712;
28.[Yourgift B&H]=713;
28.[Yourgift H&T]=714;
28.[Yourgift F&F]=715;
28.[Yourgift W&D]=716;
28.[Yourgift G&C]=717;
//
// **********************************************************************************************************************************************
// Terminal type 29 (AT CARD COMPLETE INGENICO U32 / SMART / ZVT)
// The card recognition is based on CARD TYPE (Kartenart BMP 8A) and PAYMENT TYPE (Zahlart BMP 19).
// **********************************************************************************************************************************************
// CHINA UNION PAY ---------------------
29.[198]=12,CHINA UNION PAY;
// girocard ---------------------------
29.[5]=9,GIROCARD;
// EAPS -------------------------------
29.[7]=8,EAPS;
// girocard deutsche Lastschrift ------
29.[9]=409,GIROCARD DE LASTSCHRIFT;
// VISA electron ----------------------
29.[11]=10,VISA ELECTRON;
// V PAY ------------------------------
29.[13]=11,V PAY;
// MAESTRO ----------------------------
29.[46]=1;
// MASTERCARD -------------------------
29.[6]=2;
// DINERS -----------------------------
29.[12]=4;
// VISA -------------------------------
29.[10]=5;
// AMEX -------------------------------
29.[8]=6;
// JCB --------------------------------
29.[14]=3;
// MAESTRO DE / ELV -------------------
29.[2ELV]=410;
// MAESTRO DE / OLV -------------------
29.[2OLV]=411;
// MAESTRO DE / ec-CASH ---------------
29.[2CASH]=412;
// MAESTRO DE / default ---------------
29.[2]=401;
// GELDKARTE --------------------------
29.[30]=402;
//IKEA FAMILY PAYCARD------------------
29.[76]=203,IKEA Family Paycard;
// HORNBACH Profi ---------------------
29.[137]=420,HORNBACH Profi;
// HORNBACH Welt ----------------------
29.[138]=421,HORNBACH Welt;
// HORNBACH Welt ----------------------
29.[157]=422,HORNBACH Gutscheinkarte; 
// INTERCARD GUTSCHEINKARTE------------
29.[240]=440,IC-Gutscheinkarte;
//-------------------------------------
// Comfort Card -----------------------
29.[42]=442,Comfort Card;
// Breuninger--------------------------
29.[38]=438,Breuninger;
//
// Prepaid Phone Cards ----------------
29.[+414]=414,AnniCard;
29.[+AnniCard]=414,AnniCard;
//
29.[212]=441,T-D1 XTRA;
29.[+T-D1 XTRA]=441,T-D1 XTRA;
29.[+T-D1]=441,T-D1 XTRA;
29.[+XTRA]=441,T-D1 XTRA;
//
29.[191]=479,Vodafone CallYa;
29.[+Vodafone CallYa]=479,Vodafone CallYa;
29.[+Vodafone]=479,Vodafone CallYa;
29.[+CallYa]=479,Vodafone CallYa;
//
29.[+80]=480,E-Plus Free&Easy;
29.[+E-Plus Free&Easy]=480,E-Plus Free&Easy;
29.[+E-Plus]=480,E-Plus Free&Easy;
29.[+Free&Easy]=480,E-Plus Free&Easy;
//
29.[188]=481,O2 LOOP;
29.[+O2 LOOP]=481,O2 LOOP;
29.[+O2]=481,O2 LOOP;
29.[+LOOP]=481,O2 LOOP;
//
29.[+431]=431,Premiere Flex;
29.[+Premiere Flex]=431,Premiere Flex;
29.[+Premiere]=431,Premiere Flex;
29.[+Flex]=431,Premiere Flex;
//
29.[189]=405,gobananas;
29.[+gobananas]=405,gobananas;
//
29.[+352]=452,Paysafecard;
29.[+Paysafecard]=452,Paysafecard;
//
// 218 OBB VORTEILSKARTE---------------
29.[228]=218;
// 219 SHOPIN-KARTE--------------------
29.[230]=219, SHOPIN-KARTE;
// 220 TLAPA-KARTE---------------------
29.[231]=220,TLAPA-KARTE; 
// AUSTRIA CARD -----------------------
29.[217]=217,Austria Card;
//
//SCHLECKER CARDS------------------
29.[807]=484,SCHLECKER PREPAID;
29.[249]=486,smobil;
29.[250]=487,Schlecker Zusatz;
//VITALSANA-----------------------
29.[808]=485,VITALSANA;
//MOBILE CARDS--------------------
29.[246]=488,FONIC;
29.[206]=489,BILDmobil;
29.[205]=490,Blau.de;
29.[207]=491,Congstar;
29.[475]=492,Lebara Mobile;
29.[248]=493,Simyo;
29.[884]=494,Lycamobile;
29.[917]=495,GT mobile;
//AVS -----------------------------
29.[253]=496,AVS Gutscheinkarte;

//For the function READ CARD the recognition must be done by the card number
// MAESTRO ----------------------------
29.[+67]=1;
// COMFORT CARD -----------------------
29.[+564191]=442,Comfort Card;
// MASTERCARD -------------------------
29.[+5]=2;
// DINERS -----------------------------
29.[+36]=4;
// VISA -------------------------------
29.[+4]=5;
// AMEX -------------------------------
29.[+37]=6;
// JCB --------------------------------
29.[+35]=3;
// **********************************************************************************************************************************************
// Terminal type 29 (DE INGENICO i3380 (U32) / SMART) >>>>>> Atos Card-IDs <<<<<<
// The card recognition is based on CARD TYPE (Kartenart BMP 8A) and PAYMENT TYPE (Zahlart BMP 19).
// **********************************************************************************************************************************************
// MAESTRO ----------------------------
//29.[21]=1;
// MASTERCARD -------------------------
//29.[1]=2;
// DINERS -----------------------------
//29.[4]=4;
// VISA -------------------------------
//29.[3]=5;
// AMEX -------------------------------
//29.[2]=6;
// MAESTRO DE / ELV -------------------
//29.[0ELV]=410;
// MAESTRO DE / OLV -------------------
//29.[0OLV]=411;
// MAESTRO DE / ec-CASH ---------------
//29.[0CASH]=412;
// MAESTRO DE / default ---------------
//29.[0]=401;
// GELDKARTE --------------------------
//29.[30]=402;
//
//For the function READ CARD the recognition must be done by the card number
// MAESTRO ----------------------------
//29.[+67]=1;
// COMFORT CARD -----------------------
//29.[+564191]=442,Comfort Card;
// MASTERCARD -------------------------
//29.[+5]=2;
// DINERS -----------------------------
//29.[+36]=4;
// VISA -------------------------------
//29.[+4]=5;
// AMEX -------------------------------
//29.[+37]=6;
// JCB --------------------------------
//29.[+35]=3;
//
// **********************************************************************************************************************************************
// Terminal type 30 (DE elPay)
// **********************************************************************************************************************************************
// MAESTRO DE / ELV -------------------
30.[1ELV]=410,ec National ELV;
// MAESTRO DE / ECC -------------------
30.[99]=412,ec-Cash Zahlung;
30.[4]=412,ec Kundenkarte;
// MAESTRO DE / OLV -------------------
30.[1]=411,ec National OLV;
// MAESTRO ----------------------------
30.[2]=1,ec International;
30.[3]=1,ec Ausland;
// VISA -------------------------------
30.[5]=5,Visa;
// MASTERCARD -------------------------
30.[6]=2,Eurocard;
// DINERS -----------------------------
30.[7]=4,Diners;
// AMEX -------------------------------
30.[8]=6,Amex;
// JCB --------------------------------
30.[9]=3,JCB;
// Breuninger -------------------------
30.[10]=438,Breuninger;
// IKEA FAMILY PLUS -------------------
30.[14]=403,IKEA Family Karte;
//
// **********************************************************************************************************************************************
// Terminal type 31 (IT INGENICO ABI Microcircuito ECR Protocol):
// The card recognition is primarily based on the CARD NUMBER PREFIX (Protocol 14) or the ACQUIRER ID (Protocol 12 and 17)
// **********************************************************************************************************************************************
// Protocol Version 12 and 17 ---------
// MASTERCARD -------------------------
31.[00000000070]=2,MASTERCARD;
31.[70]=2,MASTERCARD;
// MAESTRO ----------------------------
31.[00000000066]=1,MAESTRO;
31.[66]=1,MAESTRO;
// VISA -------------------------------
31.[00000000068]=5,VISA;
31.[68]=5,VISA;
// DINERS -----------------------------
31.[00000000005]=4,DINERS;
31.[5]=4,DINERS;
// AMEX -------------------------------
31.[00000000002]=6,AMERICAN EXPRESS;
31.[00000080006]=6,AMERICAN EXPRESS;
31.[2]=6,AMERICAN EXPRESS;
// JCB --------------------------------
31.[00000000067]=3,JCB;
31.[67]=3,JCB;
// PAGOBANCOMAT (DOMESTIC MAESTRO)-----
31.[00000000060]=801,PAGOBANCOMAT;
31.[60]=801,PAGOBANCOMAT;
31.[00000003226]=801,PAGOBANCOMAT;
31.[3226]=801,PAGOBANCOMAT;
31.[00000002008]=801,PAGOBANCOMAT;
31.[2008]=801,PAGOBANCOMAT;
31.[00000003500]=801,PAGOBANCOMAT;
31.[3500]=801,PAGOBANCOMAT;
// KEY CLIENT -------------------------
31.[00000000003]=802,KEY CLIENT;
31.[3]=802,KEY CLIENT;
// CARTASI ----------------------------
31.[00000000004]=803,CARTASI;
31.[4]=803,CARTASI;
//31.[00000080006]=803,CARTASI;
//31.[80006]=803,CARTASI;
// AGOS -------------------------------
31.[00000000006]=804,AGOS;
31.[6]=804,AGOS;
// FINDOMESTIC ------------------------
31.[00000000009]=805,FINDOMESTIC;
31.[9]=805,FINDOMESTIC;
//
// Protocol Version 14 ----------------
// MASTERCARD -------------------------
31.[+50]=2,MASTERCARD;
31.[+51]=2,MASTERCARD;
31.[+52]=2,MASTERCARD;
31.[+53]=2,MASTERCARD
31.[+54]=2,MASTERCARD;
31.[+55]=2,MASTERCARD;
// MAESTRO ----------------------------
31.[+67]=1,MAESTRO;
31.[+56]=1,MAESTRO;
31.[+57]=1,MAESTRO;
31.[+58]=1,MAESTRO;
31.[+59]=1,MAESTRO;
// VISA -------------------------------
31.[+4]=5,VISA;
// DINERS -----------------------------
31.[+36]=4,DINERS;
31.[+38]=4,DINERS;
31.[+39]=4,DINERS;
// AMEX -------------------------------
31.[+34]=6,AMERICAN EXPRESS;
31.[+37]=6,AMERICAN EXPRESS;
// JCB --------------------------------
31.[+35]=3,JCB;
//
// **********************************************************************************************************************************************
// Terminal type 32 (ES INGENICO Terminal controlado via serie):
// The card recognition is primarily based on the CARD NUMBER PREFIX.
// **********************************************************************************************************************************************
//
// MASTERCARD -------------------------
32.[+50]=2,MASTERCARD;
32.[+51]=2,MASTERCARD;
32.[+52]=2,MASTERCARD;
32.[+53]=2,MASTERCARD
32.[+54]=2,MASTERCARD;
32.[+55]=2,MASTERCARD;
// MAESTRO ----------------------------
32.[+67]=1,MAESTRO;
32.[+56]=1,MAESTRO;
32.[+57]=1,MAESTRO;
32.[+58]=1,MAESTRO;
32.[+59]=1,MAESTRO;
// VISA -------------------------------
32.[+4]=5,VISA;
// DINERS -----------------------------
32.[+36]=4,DINERS;
32.[+38]=4,DINERS;
32.[+39]=4,DINERS;
// AMEX -------------------------------
32.[+34]=6,AMERICAN EXPRESS;
32.[+37]=6,AMERICAN EXPRESS;
// JCB --------------------------------
32.[+35]=3,JCB;
//
// **********************************************************************************************************************************************
// Terminal type 33 (PL First Data / Polcard ECR-POS Interface):
// The card recognition is not possible. This protocol will always return "CARD UNKNOWN"
// **********************************************************************************************************************************************
//
// **********************************************************************************************************************************************
// Terminal type 34 (AT PAYLIFE):
// The card recognition is based on the CARD NAME, given by the interface.
// (As default field CCC from p_belegzeile_1 or m_belegzeile_1, (supported by terminal software version 1.64 and greater) 
//  else m_name or, in the case of debit cards, the 3 first characters of p_text
//  else by card name)
// **********************************************************************************************************************************************
// MAESTRO -----------------------------
34.[d01]=1;
34.[d02]=1;
34.[edc]=1;
// MASTERCARD --------------------------
34.[d05]=2;
34.[c01]=2;
34.[c02]=2;
34.[KMC]=2;
34.[+mastercard]=2;
34.[+mc ]=2;
// JCB --------------------------------
34.[KJB]=3;
34.[d11]=3;
34.[c06]=3;
34.[+jcb]=3;
// DINERS -----------------------------
34.[d10]=4;
34.[c05]=4;
34.[KDI]=4;
34.[+diners]=4;
// VISA ELECTRON-----------------------
34.[+visa elec]=10;
// V PAY-------------------------------
34.[d07]=11;
34.[+v pay]=11;
34.[KVP]=11;
// VISA -------------------------------
34.[KVI]=5;
34.[d08]=5;
34.[c03]=5;
34.[+visa]=5;
34.[citibank visa]=5;
34.[hanseatic bank]=5;
34.[anzsmartpay]=5;
34.[ykb worldcard]=5;
// AMEX -------------------------------
34.[KAM]=6;
34.[d09]=6;
34.[c04]=6;
34.[+american]=6;
34.[+amex]=6;
// QUICK PIN based---------------------
34.[d06]=200;
34.[QCK]=200;
// BANKOMAT (MAESTRO AT) PIN based-----
34.[B-K]=201;
// BANKOMAT PIN based (not guaranteed)-
34.[BKN]=201;
34.[bkn]=201;
// JAPAN AIRLINES ---------------------
34.[+japan]=7;
// Euro Alliance of Payment Schemes----
34.[+eaps]=8;
// CUP (China UnionPay)----------------
34.[d12]=12;
34.[c07]=12;
34.[+cup]=12;
34.[+KCU]=12;
34.[+china]=12;
// FLOTTENKARTE (TYP 4)
34.[TYP4]=204,Flottenkarte;
// LOKALE KARTE (TYP 3)
34.[TYP3]=205;
//
// **********************************************************************************************************************************************
// Terminal type 35 (CH CCV JERONIMO Vx810 with CCV JIL):
// The card recognition is based on the ISSUER NUMBER and Application-ID
// **********************************************************************************************************************************************
// MAESTRO ----------------------------
35.[7]=1;
35.[07]=1;
35.[+A0000000043060]=1;
35.[+A0000001570021]=1;
// MASTERCARD -------------------------
35.[2]=2;
35.[02]=2;
35.[+A0000000041010]=2;
35.[+A0000001570020]=2;
//M-Budget MasterCard
35.[25]=2;
35.[A0000000000008]=2;
// JCB --------------------------------
35.[6]=3;
35.[06]=3;
35.[+A0000000651010]=3;
35.[+A0000001570040]=3;
// DINERS -----------------------------
35.[43]=4;
35.[+A0000001884443]=4;
35.[+A0000001574443]=4;
35.[+A0000001570060]=4;
// VISA -------------------------------
35.[5]=5;
35.[05]=5;
35.[+A0000000031010]=5;
35.[+A0000001570030]=5;
// VISA ELECTRON-----------------------
35.[+A0000000032010]=10;
35.[+A0000001570031]=10;
//V PAY -------------------------------
35.[+A0000000032020]=11,V PAY;
// AMEX -------------------------------
35.[40]=6;
35.[+A0000001570010]=6;
35.[+A00000002501]=6;
35.[+A0000000291010]=6;
// CHINA UNION PAY --------------------
35.[9]=12,CHINA UNION PAY;
35.[09]=12,CHINA UNION PAY;
35.[A000000157446003]=12,CHINA UNION PAY;
35.[A000000157446004]=12,CHINA UNION PAY;
35.[A000000157446005]=12,CHINA UNION PAY;
35.[A000000157446006]=12,CHINA UNION PAY;
35.[A000000157446009]=12,CHINA UNION PAY;
// MAESTRO CH -------------------------
35.[1]=100;
35.[01]=100;
35.[+A0000000101030]=100;
35.[+A0000001570022]=100;
// M-CARD -----------------------------
35.[22]=101;
35.[+A0000001570100]=101;
// POSTCARD ---------------------------
35.[21]=102;
35.[+A0000001110101]=102;
35.[+A0000001999999]=102;
35.[+A0000001999998]=102;
35.[+A0000001570051]=102;
35.[+A0000001570050]=102;
35.[+A0000001574445]=102;
35.[+A0000001574446]=102;
// BERN CARD --------------------------
35.[+A0000001570107]=103;
// ZUERI CARD -------------------------
35.[+A0000001570106]=104;
// BASLER CARD ------------------------
35.[+A0000001570108]=105;
// CASH -------------------------------
35.[+A0000001570023]=106;
// PHARMACARD --------------------------
35.[+A0000001570105]=107;
// MOEVENPICK -------------------------
35.[+A0000001570102]=108;
// JELMOLI SHOPPING BONUS CARD --------
// JELMOLI PAYCARD --------------------
35.[a0000001574462]=137;
35.[68]=110;
35.[81]=110;
35.[+A0000001570103]=110;
35.[+A000000157010B]=110;
35.[+A000000003000375]=110;
// MY ONE -----------------------------
35.[+A0000001570104]=111;
// ORANGE -----------------------------
35.[75]=112;
// Sunrise ----------------------------
35.[76]=113;
// SWISSCOM ---------------------------
35.[77]=114;
//COOP SUPERCARD PLUS MASTERCARD-------
35.[24]=116;
35.[A0000001574444]=116;
35.[A0000000049999C000020001]=116;
//COOP SUPERCARD PLUS VISA-------------
35.[26]=134;
35.[A0000001574458]=134;
35.[A00000000300037562]=134;
// POWER CARD -------------------------
35.[+A000000157010D]=117;
// WIR --------------------------------
35.[50]=118;
35.[+A000000157010C]=118;
//REKA  -------------------------------
35.[90]=120;
35.[+A000000157010E]=120;
35.[+D7560000010101]=120;
// JGIFT (JELMOLI)---------------------
35.[+A000000157444E]=122,J-Geschenkkarte;
// COMMTRAIN/ADUNO CARDS --------------
35.[+A0000001574448]=123,Aduno Kundenkarte;
35.[+A0000001574449]=124,Swiss Bonus Card;
35.[+A000000157444A]=125,ABO Card;
// MEDIAMARKT --------------
35.[+A0000001570109]=126,Mediamarkt Card;
// YALLO ------------------------------
35.[73]=127,Yallo;
// COOP MOBILE ------------------------
35.[78]=128,Coop Mobile;
// PHONECARD ---------------------------
35.[79]=129,phoneCard;
// ORANGECLICK.CH ----------------------
35.[80]=130,orangeclick.ch;
// M-BUDGET MOBILE ---------------------
35.[82]=131,M-Budget Mobile;
// M-BUDGET ---------------------------- (M-Budget is not a Mastercard when accepted by a Migros Merchant)
35.[D7560000300101]=132,M-Budget;
//SWISSCADEAU
35.[A000000157445A]=136,SwissCadeau;
//BONCARD
35.[A0000001574455]=160,BONARD POINTS;
35.[A000000157445B]=161,BONCARD PAY;
35.[66]=160,BONARD POINTS;
35.[67]=161,BONCARD PAY;
//
// **********************************************************************************************************************************************
// Terminal type 36 (FR/ES AXIS C3):
// The card recognition is based on the cCardType (FFU: in combination with SSCard); fallback recognition by PAN  
// **********************************************************************************************************************************************
//AMEX ---------------------------------
36.[6]=6,AMERICAN EXPRESS;
//China Union Pay Natixis/China Union Pay 
36.[m]=12,CHINA UNION PAY;
//Diners Club de France ----------------
36.[7]=4,DINERS CLUB FRANCE;
//JCB piste/JCB EMV --------------------
36.[D]=3,JCB;
36.[+35]=3,JCB;
// MASTERCARD (by PAN)------------------
36.[+50]=2,MASTERCARD;
36.[+51]=2,MASTERCARD;
36.[+52]=2,MASTERCARD;
36.[+53]=2,MASTERCARD;
36.[+54]=2,MASTERCARD;
36.[+55]=2,MASTERCARD;
// MAESTRO (by PAN)---------------------
36.[+67]=1,MAESTRO;
36.[+63]=1,MAESTRO;
36.[+56]=1,MAESTRO;
36.[+57]=1,MAESTRO;
36.[+58]=1,MAESTRO;
36.[+59]=1,MAESTRO;
// VISA (by PAN)-----------------------
//36.[+4970]=900,CARTE BLEUE;
//36.[+4971]=900,CARTE BLEUE;
//36.[+4973]=900,CARTE BLEUE;
//36.[+4974]=900,CARTE BLEUE;
//36.[+4975]=900,CARTE BLEUE;
//36.[+4976]=900,CARTE BLEUE;
//36.[+4978]=900,CARTE BLEUE;
36.[+4]=5,VISA;
//ACCORD ------------------------------
36.[p]=901,ACCORD EMV;
36.[V]=901,ACCORD Piste; 
36.[w]=901,ACCORD sans contact;
//Alphyra (Payzone) --------------------
36.[k]=902,ALPHYRA;
//Caftria Casino ---------------------
36.[Q]=903,CAFETERIA CASINO;
//Auchan Tlcom -----------------------
36.[u]=904,AUCHAN TELECOM;
//PNF Crdit Mutuel --------------------
36.[W]=905,PNF CREDIT MUTUEL;
//Employ ED ---------------------------
36.[r]=906,EMPLOYE ED;
//EVEREST -------------------------------
36.[5]=907,EVEREST;
//COFINOGA -----------------------------
36.[l]=908,COFINOGA EMV; 
36.[2]=908,COFINOGA Piste et Sans Contact;
//Chque -------------------------------
36.[M]=909,CHEQUE;
36.[N]=909,CHEQUE;
36.[O]=909,CHEQUE;
36.[P]=909,CHEQUE;
//Caldonienne de Service Bancaire ------
36.[d]=910,CALEDONIENNE DE SERVICE BANCAIRE;
//Reflexe/Aurore - protocole CETNCB CETDIS-
36.[8]=911,AURORE;
//Datavantage (GIFTCARD) ------------------
36.[i]=912,DATAVANTAGE;
//Edel - Leclerc --------------------------
36.[H]=913,EDEL;
//Total - parking -------------------------
36.[X]=914,ELF;
//Pluriel - FranFinance -------------------
36.[9]=915,FFI;
//Fnac ------------------------------------
36.[g]=916,FNAC; 
//Finaref ---------------------------------
36.[F]=917,FINAREF; 
//Gestion de Avoirs -----------------------
36.[z]=918,GAV; 
//Galerie Lafayette -----------------------
36.[c]=919,GLF; 
//Magellan --------------------------------
36.[y]=920,MGL;
//Multissime ------------------------------
36.[U]=921,MULTISSIME;
//PNF Optalion - crdit Lyonnais ----------
36.[h]=922,OPTALION;
//Pass piste/Pass EMV ---------------------
36.[3]=923,PASS;
//Pegasus ---------------------------------
36.[v]=924,PGS;
//Mono (Porte Monnaie Electronique) ------
36.[S]=925,PME;
//Promostim (Record Card) -----------------
36.[a]=926,PROMOSTIM;
//Prosodie --------------------------------
36.[j]=927,PROSODIE;
//Sofinco ---------------------------------
36.[B]=928,SOFINCO;
//Sodelem - carte ptrole -----------------
36.[q]=929,SODELEM;
//Smiles ----------------------------------
36.[Y]=930,SMILES;
//
// *******************************************************************************************************************************************
// Terminal type 37 (CH INNOCARD ARTEMA DESK / ZVT):
// The card recognition is based on CARD TYPE (Kartenart BMP 8A) and PAYMENT TYPE (Zahlart BMP 19).
// *******************************************************************************************************************************************
// CHINA UNION PAY ---------------------
37.[198]=12,CHINA UNION PAY;
// girocard ---------------------------
37.[5]=9,GIROCARD;
// EAPS -------------------------------
37.[7]=8,EAPS;
// girocard deutsche Lastschrift ------
37.[9]=409,GIROCARD DE LASTSCHRIFT;
// VISA electron ----------------------
37.[11]=10,VISA ELECTRON;
// V PAY ------------------------------
37.[13]=11,V PAY;
//POSTCARD ----------------------------
37.[236]=102,POSTFINANCE CARD;
// MAESTRO ----------------------------
37.[46]=1;
// MASTERCARD -------------------------
37.[6]=2;
// DINERS -----------------------------
37.[12]=4;
// VISA -------------------------------
37.[10]=5;
// AMEX -------------------------------
37.[8]=6;
// JCB --------------------------------
37.[14]=3;
// HORNBACH Profi ---------------------
37.[137]=420,HORNBACH Profi;
// HORNBACH Welt ----------------------
37.[138]=421,HORNBACH Welt;
// HORNBACH Welt ----------------------
37.[157]=422,HORNBACH Gutscheinkarte;
// INTERCARD GUTSCHEINKARTE------------
37.[240]=440,IC-Gutscheinkarte;
// Comfort Card -----------------------
37.[42]=442,Comfort Card;
// Breuninger--------------------------
37.[38]=438,Breuninger;
37.[+352]=452,Paysafecard;
37.[+Paysafecard]=452,Paysafecard;
// BONCARD ----------------------------
37.[23]=160,boncard POINTS;
37.[25]=161,boncard PAY;
//For the function READ CARD the recognition must be done by the card number
// MAESTRO ----------------------------
37.[+67]=1;
// COMFORT CARD -----------------------
37.[+564191]=442,Comfort Card;
// MASTERCARD -------------------------
37.[+5]=2;
// DINERS -----------------------------
37.[+36]=4;
// VISA -------------------------------
37.[+4]=5;
// AMEX -------------------------------
37.[+37]=6;
// JCB --------------------------------
37.[+35]=3;
//
// *******************************************************************************************************************************************
// Terminal type 38 (CH INNOCARD OPTIMUM FAMILY / ZVT):
// The card recognition is based on CARD TYPE (Kartenart BMP 8A) and PAYMENT TYPE (Zahlart BMP 19).
// *******************************************************************************************************************************************
// girocard ---------------------------
38.[5]=9,GIROCARD;
// EAPS -------------------------------
38.[7]=8,EAPS;
// girocard deutsche Lastschrift ------
38.[9]=409,GIROCARD DE LASTSCHRIFT;
// VISA electron ----------------------
38.[11]=10,VISA ELECTRON;
// V PAY ------------------------------
38.[13]=11,V PAY;
//POSTCARD ----------------------------
38.[236]=102,POSTFINANCE CARD;
// MAESTRO ----------------------------
38.[46]=1;
// MASTERCARD -------------------------
38.[6]=2;
// DINERS -----------------------------
38.[12]=4;
// VISA -------------------------------
38.[10]=5;
// AMEX -------------------------------
38.[8]=6;
// JCB --------------------------------
38.[14]=3;
// HORNBACH Profi ---------------------
38.[137]=420,HORNBACH Profi;
// HORNBACH Welt ----------------------
38.[138]=421,HORNBACH Welt;
// HORNBACH Welt ----------------------
38.[157]=422,HORNBACH Gutscheinkarte;
// INTERCARD GUTSCHEINKARTE------------
38.[240]=440,IC-Gutscheinkarte;
// Comfort Card -----------------------
38.[42]=442,Comfort Card;
// Breuninger--------------------------
38.[38]=438,Breuninger;
38.[+352]=452,Paysafecard;
38.[+Paysafecard]=452,Paysafecard;
// BONCARD ----------------------------
38.[23]=160,boncard POINTS;
38.[25]=161,boncard PAY;
//For the function READ CARD the recognition must be done by the card number
// MAESTRO ----------------------------
38.[+67]=1;
// COMFORT CARD -----------------------
38.[+564191]=442,Comfort Card;
// MASTERCARD -------------------------
38.[+5]=2;
// DINERS -----------------------------
38.[+36]=4;
// VISA -------------------------------
38.[+4]=5;
// AMEX -------------------------------
38.[+37]=6;
// JCB --------------------------------
38.[+35]=3;
// **********************************************************************************************************************************************
// Terminal type 39 (DE PAYSYS):
// The card recognition is based on ISSUER NUMBER and CARD NUMBER.
// **********************************************************************************************************************************************
// MAESTRO ----------------------------
39.[7]=1;
39.[07]=1;
// MASTERCARD -------------------------
39.[2]=2;
39.[02]=2;
// JCB --------------------------------
39.[6]=3;
39.[06]=3;
// DINERS -----------------------------
39.[43]=4;
// VISA -------------------------------
39.[5]=5;
39.[05]=5;
//V PAY -------------------------------
39.[96]=11,V PAY;
// AMEX -------------------------------
39.[40]=6;
// MAESTRO CH -------------------------
39.[1]=100;
39.[01]=100;
// M-CARD -----------------------------
39.[22]=101;
// POSTCARD ---------------------------
39.[21]=102;
// BERN CARD --------------------------
39.[41]=103;
39.[42]=103;
39.[45]=103;
// MOEVENPICK -------------------------
39.[46]=108;
//LOKALKARTE (READ OVER USB-PORT)
39.[80]=135;
// JELMOLI SHOPPING BONUS CARD --------
39.[81]=110;
// MYONE ------------------------------
39.[84]=111;
//COOP SUPERCARD PLUS MASTERCARD-------
39.[24]=116;
//COOP SUPERCARD PLUS VISA-------------
39.[26]=134;
//REKA  -------------------------------
39.[20]=120;
// BONCARD ----------------------------
39.[66]=160,BONARD POINTS;
39.[67]=161,BONCARD PAY;
//if recognition by Issuer Number fails, try by card number prefix
// MASTERCARD -------------------------
39.[+50]=2;
39.[+51]=2;
39.[+52]=2;
39.[+53]=2
39.[+54]=2;
39.[+55]=2;
// MAESTRO ----------------------------
39.[+67]=1;
39.[+56]=1;
39.[+57]=1;
39.[+58]=1;
39.[+59]=1;
// VISA -------------------------------
39.[+4]=5;
// DINERS -----------------------------
39.[+36]=4;
39.[+38]=4;
39.[+39]=4;
// AMEX -------------------------------
39.[+34]=6;
39.[+37]=6;
// JCB --------------------------------
39.[+35]=3;
//
// **********************************************************************************************************************************************
// Terminal type 40 (SK SLOVENSKA SPORITELNA):
// The card recognition is based on Aplication ID, Card Type and Application Pref. Name.
// **********************************************************************************************************************************************
// MAESTRO ------------------------
40.[+A0000000043060]=1;
40.[+A0000001570021]=1;
40.[+A0000000101030]=1;
40.[+A0000001570022]=1;
40.[+maestro]=1;
// MASTERCARD ---------------------
40.[+A0000000041010]=2;
40.[+A0000001570020]=2;
40.[A0000001574444]=2;
40.[A0000000049999C000020001]=2;
40.[mastercard]=2;
// JCB ---------------------------
40.[+A0000000651010]=3;
40.[+A0000001570040]=3;
40.[jcb]=3;
// DINERS ------------------------
40.[+A0000001884443]=4;
40.[+A0000001574443]=4;
40.[+A0000001570060]=4;
40.[diners]=4;
// VISA --------------------------
40.[+A0000000031010]=5;
40.[+A0000001570030]=5;
40.[A0000001574458]=5;
40.[A00000000300037562]=5;
40.[visa]=5;
// VISA ELECTRON------------------
40.[+A0000000032010]=10;
40.[+A0000001570031]=10;
40.[visa electron]=10;
//V PAY --------------------------
40.[+A0000000032020]=11;
40.[v pay]=11;
40.[vpay]=11;
40.[v-pay]=11;
// AMERICAN EXPRESS --------------
40.[+A0000001570010]=6;
40.[+A00000002501]=6;
40.[+A0000000291010]=6;
40.[+american]=6;
40.[amex]=6;
//
// **********************************************************************************************************************************************
// Terminal type 41 (CH MFGroup Payment Server Gateway):
// The card recognition is based on CardType, Card Number Prefix and/or CardName
// **********************************************************************************************************************************************
// EXLIBRIS GESCHENKKARTE -------------
41.[10]=165,Exlibris Geschenkkarte;
//
// **********************************************************************************************************************************************
// Terminal type 42 (DE/AT/CH easycash PrePayPlus):
// The card recognition is based on Card Number Prefix
// **********************************************************************************************************************************************
// HORNBACH PROFICARD------------
42.[+60038803]=1002,HORNBACH PROFICARD LUX;
// HORNBACH GUTSCHEINKARTE--------
42.[+928000116]=422,HORNBACH GUTSCHEINKARTE;
//
// **********************************************************************************************************************************************
// Terminal type 43 (DE/AT/CH Cards & Systems IBRO30):
// The card recognition is based on Card Number Prefix
// **********************************************************************************************************************************************
// HORNBACH ProfiCard AT--------------
43.[+600388021]=420,HORNBACH ProfiCard;
43.[+600388024]=420,HORNBACH ProfiCard;
// HORNBACH ProfiCard CH--------------
43.[+600388061]=420,HORNBACH ProfiCard;
43.[+600388064]=420,HORNBACH ProfiCard;
// HORNBACH Projektweltkarte AT-------
43.[+600388022]=421,HORNBACH ProjektWelt;
//
// *******************************************************************************************************************************************
// Terminal type 44 (CH INNOCARD ICP BIA / ZVT):
// The card recognition is based on CARD TYPE (Kartenart BMP 8A) and PAYMENT TYPE (Zahlart BMP 19).
// *******************************************************************************************************************************************
// CHINA UNION PAY ---------------------
44.[198]=12,CHINA UNION PAY;
// girocard ---------------------------
44.[5]=9,GIROCARD;
// EAPS -------------------------------
44.[7]=8,EAPS;
// girocard deutsche Lastschrift ------
44.[9]=409,GIROCARD DE LASTSCHRIFT;
// VISA electron ----------------------
44.[11]=10,VISA ELECTRON;
// V PAY ------------------------------
44.[13]=11,V PAY;
//POSTCARD ----------------------------
44.[236]=102,POSTFINANCE CARD;
// MAESTRO ----------------------------
44.[46]=1;
// MASTERCARD -------------------------
44.[6]=2;
// DINERS -----------------------------
44.[12]=4;
// VISA -------------------------------
44.[10]=5;
// AMEX -------------------------------
44.[8]=6;
// JCB --------------------------------
44.[14]=3;
// HORNBACH Profi ---------------------
44.[137]=420,HORNBACH Profi;
// HORNBACH Welt ----------------------
44.[138]=421,HORNBACH Welt;
// HORNBACH Welt ----------------------
44.[157]=422,HORNBACH Gutscheinkarte;
// INTERCARD GUTSCHEINKARTE------------
44.[240]=440,IC-Gutscheinkarte;
// Comfort Card -----------------------
44.[42]=442,Comfort Card;
// Breuninger--------------------------
44.[38]=438,Breuninger;
44.[+352]=452,Paysafecard;
44.[+Paysafecard]=452,Paysafecard;
// BONCARD ----------------------------
44.[23]=160,boncard POINTS;
44.[25]=161,boncard PAY;
//For the function READ CARD the recognition must be done by the card number
// MAESTRO ----------------------------
44.[+67]=1;
// COMFORT CARD -----------------------
44.[+564191]=442,Comfort Card;
// MASTERCARD -------------------------
44.[+5]=2;
// DINERS -----------------------------
44.[+36]=4;
// VISA -------------------------------
44.[+4]=5;
// AMEX -------------------------------
44.[+37]=6;
// JCB --------------------------------
44.[+35]=3;
//
// *******************************************************************************************************************************************
// Terminal type 45 Reserved for future use
// *******************************************************************************************************************************************
// 
// *******************************************************************************************************************************************
// Terminal type 46 BAXI (SE/DK/NO/FI/BALTIC STATES/PL):
// The card recognition is based on ISSUER-ID.
// *******************************************************************************************************************************************
// VISA -------------------------------
46.[3]=5,VISA Udenlandsk;
46.[39]=5,VISA;
46.[57]=1101,VISA Danmark;
// MASTERCARD--------------------------
46.[4]=2,MASTERCARD Udenlandsk;
46.[58]=1102,MASTERCARD DK;
// AMEX -------------------------------
46.[5]=6,AMEX Udenlandsk;
46.[61]=1105,AMEX DK;
// DINERS -----------------------------
46.[6]=4,DINERS Udenlandsk;
46.[60]=1104,DINERS DK;
// JCB - Japanese Credit Banc ---------
46.[11]=3,JCB;
// MAESTRO ----------------------------
46.[14]=1,MAESTRO Udenlandsk;
46.[59]=1103,MAESTRO DK;
// CUP --------------------------------
46.[68]=12,CUP;
// DOMESTIC CARDS ---------------------
46.[50]=1100,DanKort;
46.[64]=1106,PBS Gavekort;
//46.[64]=1106,PBS Kjedekort;
46.[77]=1107,PBS Centerkort;
46.[65]=1108,Forbrugsforeningen;
46.[66]=1109,Ikano Finans;
46.[67]=1110,SparExpress;
//
// *******************************************************************************************************************************************
// Terminal type 47 Reserved for future use
// *******************************************************************************************************************************************
//
// *******************************************************************************************************************************************
// Terminal type 48 Reserved for future use
// *******************************************************************************************************************************************
// **********************************************************************************************************************************************
// Terminal type 49 (US VERIFONE PCCHARGE THINCLIENT):
// The card recognition is based on pan
// **********************************************************************************************************************************************
// VISA -------------------------------
49.[+4]=5,VISA;
// MC - MASTERCARD --------------------
49.[+5]=2,MASTERCARD;
// AMEX -------------------------------
49.[+34]=6,AMERICAN EXPRESS;
49.[+37]=6,AMERICAN EXPRESS;
// JCB - Japanese Credit Banc ---------
49.[+3088]=3,JCB;
49.[+3089]=3,JCB;
49.[+309, -3095]=3,JCB;
49.[+311, -3110, 3112]=3,JCB;
49.[+3120]=3,JCB;
49.[+3158]=3,JCB;
49.[+3159]=3,JCB;
49.[+3337]=3,JCB;
49.[+3338]=3,JCB;
49.[+3339]=3,JCB;
49.[+334]=3,JCB;
49.[+3528]=3,JCB;
49.[+3529]=3,JCB;
49.[+353]=3,JCB;
49.[+354]=3,JCB;
49.[+355]=3,JCB;
49.[+356]=3,JCB;
49.[+357]=3,JCB;
49.[+358]=3,JCB;
// Disc - Discover --------------------
49.[+6011]=600,DISCOVER;
// DCCB - Diners Club -----------------
49.[+36]=4,DINERS;
49.[+38]=4,DINERS;
49.[+300]=4,DINERS;
49.[+301]=4,DINERS;
49.[+302]=4,DINERS;
49.[+303]=4,DINERS;
49.[+304]=4,DINERS;
49.[+305]=4,DINERS;
// CBLN - Carte Blanche ---------------
49.[+389]=601,CARTE BLACHE;
// JAL- Japan Airlines ----------------
49.[+1800]=7,JAL;
49.[+2131]=7,JAL;
